/* AI Model Inference.
   Copyright (C) 2024-2024 Free Software Foundation, Inc.

This file is part of GCC.

GCC is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free
Software Foundation; either version 3, or (at your option) any later
version.

GCC is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.

You should have received a copy of the GNU General Public License
along with GCC; see the file COPYING3.  If not see
<http://www.gnu.org/licenses/>.  */

#ifndef AI4C_INFER
#define AI4C_INFER

#include "system.h"
#include <math.h>

#ifndef _cbmc_
#define __CPROVER_assume(...) do {} while (0)
#endif

#define FN_ static inline __attribute__((const))

#define M_OPTION_SIZE (11)
#define M_MODE_SIZE (6)

/* sha256 */
typedef struct
{
  uint8_t  buf[64];
  uint32_t hash[8];
  uint32_t bits[2];
  uint32_t len;
  uint32_t rfu__;
  uint32_t W[64];
} sha256_context;

static const uint32_t K[64] = {
  0x428a2f98, 0x71374491, 0xb5c0fbcf, 0xe9b5dba5,
  0x3956c25b, 0x59f111f1, 0x923f82a4, 0xab1c5ed5,
  0xd807aa98, 0x12835b01, 0x243185be, 0x550c7dc3,
  0x72be5d74, 0x80deb1fe, 0x9bdc06a7, 0xc19bf174,
  0xe49b69c1, 0xefbe4786, 0x0fc19dc6, 0x240ca1cc,
  0x2de92c6f, 0x4a7484aa, 0x5cb0a9dc, 0x76f988da,
  0x983e5152, 0xa831c66d, 0xb00327c8, 0xbf597fc7,
  0xc6e00bf3, 0xd5a79147, 0x06ca6351, 0x14292967,
  0x27b70a85, 0x2e1b2138, 0x4d2c6dfc, 0x53380d13,
  0x650a7354, 0x766a0abb, 0x81c2c92e, 0x92722c85,
  0xa2bfe8a1, 0xa81a664b, 0xc24b8b70, 0xc76c51a3,
  0xd192e819, 0xd6990624, 0xf40e3585, 0x106aa070,
  0x19a4c116, 0x1e376c08, 0x2748774c, 0x34b0bcb5,
  0x391c0cb3, 0x4ed8aa4a, 0x5b9cca4f, 0x682e6ff3,
  0x748f82ee, 0x78a5636f, 0x84c87814, 0x8cc70208,
  0x90befffa, 0xa4506ceb, 0xbef9a3f7, 0xc67178f2
};

FN_
uint8_t _shb (uint32_t x, uint32_t n)
{
  return ((x >> (n & 31)) & 0xff);
} // _shb

FN_
uint32_t _shw (uint32_t x, uint32_t n)
{
  return ((x << (n & 31)) & 0xffffffff);
} // _shw

FN_
uint32_t _r (uint32_t x, uint8_t n)
{
  return ((x >> n) | _shw (x, 32 - n));
} // _r

FN_
uint32_t _Ch (uint32_t x, uint32_t y, uint32_t z)
{
  return ((x & y) ^ ((~x) & z));
} // _Ch

FN_
uint32_t _Ma (uint32_t x, uint32_t y, uint32_t z)
{
  return ((x & y) ^ (x & z) ^ (y & z));
} // _Ma

FN_
uint32_t _S0 (uint32_t x)
{
  return (_r (x, 2) ^ _r (x, 13) ^ _r (x, 22));
} // _S0

FN_
uint32_t _S1 (uint32_t x)
{
  return (_r (x, 6) ^ _r (x, 11) ^ _r (x, 25));
} // _S1

FN_
uint32_t _G0 (uint32_t x)
{
  return (_r (x, 7) ^ _r (x, 18) ^ (x >> 3));
} // _G0

FN_
uint32_t _G1 (uint32_t x)
{
  return (_r (x, 17) ^ _r (x, 19) ^ (x >> 10));
} // _G1

FN_
uint32_t _word (uint8_t *c)
{
  return (_shw (c[0], 24) | _shw (c[1], 16) | _shw (c[2], 8) | (c[3]));
} // _word

static void
_addbits (sha256_context *ctx, uint32_t n)
{
  __CPROVER_assume (__CPROVER_DYNAMIC_OBJECT (ctx));

  if (ctx->bits[0] > (0xffffffff - n))
    {
      ctx->bits[1] = (ctx->bits[1] + 1) & 0xFFFFFFFF;
    }
  ctx->bits[0] = (ctx->bits[0] + n) & 0xFFFFFFFF;
} // _addbits

static void
_hash (sha256_context *ctx)
{
  __CPROVER_assume (__CPROVER_DYNAMIC_OBJECT (ctx));

  register uint32_t a, b, c, d, e, f, g, h;
  uint32_t t[2];

  a = ctx->hash[0];
  b = ctx->hash[1];
  c = ctx->hash[2];
  d = ctx->hash[3];
  e = ctx->hash[4];
  f = ctx->hash[5];
  g = ctx->hash[6];
  h = ctx->hash[7];

  for (uint32_t i = 0; i < 64; i++)
    {
      if (i < 16)
	{
	  ctx->W[i] = _word (&ctx->buf[_shw (i, 2)]);
	}
      else
	{
	  ctx->W[i] = _G1 (ctx->W[i - 2])  + ctx->W[i - 7]
		    + _G0 (ctx->W[i - 15]) + ctx->W[i - 16];
	}

      t[0] = h + _S1 (e) + _Ch (e, f, g) + K[i] + ctx->W[i];
      t[1] = _S0 (a) + _Ma (a, b, c);
      h = g;
      g = f;
      f = e;
      e = d + t[0];
      d = c;
      c = b;
      b = a;
      a = t[0] + t[1];
    }

  ctx->hash[0] += a;
  ctx->hash[1] += b;
  ctx->hash[2] += c;
  ctx->hash[3] += d;
  ctx->hash[4] += e;
  ctx->hash[5] += f;
  ctx->hash[6] += g;
  ctx->hash[7] += h;
} // _hash

void
sha256_init (sha256_context *ctx)
{
  if (ctx != NULL)
    {
      ctx->bits[0] = ctx->bits[1] = ctx->len = 0;
      ctx->hash[0] = 0x6a09e667;
      ctx->hash[1] = 0xbb67ae85;
      ctx->hash[2] = 0x3c6ef372;
      ctx->hash[3] = 0xa54ff53a;
      ctx->hash[4] = 0x510e527f;
      ctx->hash[5] = 0x9b05688c;
      ctx->hash[6] = 0x1f83d9ab;
      ctx->hash[7] = 0x5be0cd19;
    }
} // sha256_init

void
sha256_hash (sha256_context *ctx, const void *data, size_t len)
{
  const uint8_t *bytes = (const uint8_t *)data;

  if ((ctx != NULL) && (bytes != NULL) && (ctx->len < sizeof (ctx->buf)))
    {
      __CPROVER_assume (__CPROVER_DYNAMIC_OBJECT (bytes));
      __CPROVER_assume (__CPROVER_DYNAMIC_OBJECT (ctx));
      for (size_t i = 0; i < len; i++)
	{
	  ctx->buf[ctx->len++] = bytes[i];
	  if (ctx->len == sizeof (ctx->buf))
	    {
	      _hash (ctx);
	      _addbits (ctx, sizeof (ctx->buf) * 8);
	      ctx->len = 0;
	    }
	}
    }
} // sha256_hash

void
sha256_done (sha256_context *ctx, uint8_t *hash)
{
  register uint32_t i, j;

  if (ctx != NULL)
    {
      j = ctx->len % sizeof (ctx->buf);
      ctx->buf[j] = 0x80;
      for (i = j + 1; i < sizeof (ctx->buf); i++)
	{
	  ctx->buf[i] = 0x00;
	}

      if (ctx->len > 55)
	{
	  _hash (ctx);
	  for (j = 0; j < sizeof (ctx->buf); j++)
	    {
	      ctx->buf[j] = 0x00;
	    }
	}

      _addbits (ctx, ctx->len * 8);
      ctx->buf[63] = _shb (ctx->bits[0],  0);
      ctx->buf[62] = _shb (ctx->bits[0],  8);
      ctx->buf[61] = _shb (ctx->bits[0], 16);
      ctx->buf[60] = _shb (ctx->bits[0], 24);
      ctx->buf[59] = _shb (ctx->bits[1],  0);
      ctx->buf[58] = _shb (ctx->bits[1],  8);
      ctx->buf[57] = _shb (ctx->bits[1], 16);
      ctx->buf[56] = _shb (ctx->bits[1], 24);
      _hash (ctx);

      if (hash != NULL)
	{
	  for (i = 0, j = 24; i < 4; i++, j -= 8)
	    {
	      hash[i +  0] = _shb (ctx->hash[0], j);
	      hash[i +  4] = _shb (ctx->hash[1], j);
	      hash[i +  8] = _shb (ctx->hash[2], j);
	      hash[i + 12] = _shb (ctx->hash[3], j);
	      hash[i + 16] = _shb (ctx->hash[4], j);
	      hash[i + 20] = _shb (ctx->hash[5], j);
	      hash[i + 24] = _shb (ctx->hash[6], j);
	      hash[i + 28] = _shb (ctx->hash[7], j);
	    }
	}
    }
} // sha256_done

void
sha256 (const void *data, size_t len, uint8_t *hash)
{
  sha256_context ctx;

  sha256_init (&ctx);
  sha256_hash (&ctx, data, len);
  sha256_done (&ctx, hash);
}
/* sha256 */

static float coefficient[356][10] = {
  { -0.001202732790261507, 0.20421256124973297, 0.0008969634654931724,
  -0.2505858838558197, -0.004086401779204607, 0.03011753223836422,
  0.00012006870383629575, -0.11625227332115173, -0.001972030848264694,
  0.0018470664508640766 }, { -0.008228142745792866, 0.012081502936780453,
  0.0029826753307133913, -0.12449272722005844, 0.0029766298830509186,
  0.07979818433523178, 0.00489660631865263, -0.07108338922262192,
  0.006859836168587208, 0.0070451670326292515 }, { -0.008624650537967682,
  -0.046396952122449875, -0.03131939470767975, -0.07215258479118347,
  -0.03171403333544731, -0.06464441865682602, -0.029830951243638992,
  0.11516642570495605, -0.027210921049118042, -0.027592642232775688 }, {
  0.007101533468812704, 0.12788672745227814, -0.015976447612047195,
  -0.05871947109699249, -0.022161206230521202, -0.12508492171764374,
  -0.03382435813546181, -0.0458468459546566, -0.016005748882889748,
  -0.02996719442307949 }, { -0.010423759929835796, 0.0421634167432785,
  -0.03137495368719101, -0.1427338570356369, -0.0142595786601305,
  -0.3891606330871582, -0.005455203354358673, -0.14104995131492615,
  -0.017540356144309044, -0.009234420023858547 }, { -0.0004962400416843593,
  0.08799923211336136, 0.0010081625077873468, -0.10385274142026901,
  0.001455705612897873, 0.018755201250314713, 0.0012732904870063066,
  -0.08233556151390076, 0.0008989688940346241, 0.0014089341275393963 }, {
  0.39337393641471863, -0.29290419816970825, 0.4996858239173889,
  -0.3003338873386383, 0.5005763173103333, -0.5788354873657227,
  0.4559592604637146, 0.1535145342350006, 0.4100588262081146,
  0.43764257431030273 }, { 0.4433407783508301, -0.24534298479557037,
  0.4418940246105194, -0.2674236595630646, 0.45750802755355835,
  -0.6914718747138977, 0.4248504340648651, 0.21534226834774017,
  0.381326287984848, 0.42402878403663635 }, { 0.40570271015167236,
  -0.2965546250343323, 0.4877605438232422, -0.3061105012893677,
  0.45858457684516907, -0.6169699430465698, 0.45162418484687805,
  0.043029867112636566, 0.40422892570495605, 0.4498996138572693 }, {
  0.5399827361106873, -0.23754213750362396, 0.42819300293922424,
  -0.2471727430820465, 0.4236094355583191, -0.7273492217063904,
  0.397212415933609, 0.1800859272480011, 0.3471176326274872, 0.38948121666908264
  }, { -0.1325892210006714, -0.2530541718006134, 0.47642746567726135,
  -0.2529260218143463, 0.5287042260169983, -0.7421981692314148,
  0.45938733220100403, 0.3739463984966278, 0.41974151134490967,
  0.4510754346847534 }, { -0.14016218483448029, -0.28810086846351624,
  0.5178493857383728, -0.3065412640571594, 0.5258545875549316,
  -0.6815170645713806, 0.4928705096244812, 0.3198302388191223, 0.43727907538414,
  0.489217072725296 }, { -0.06365948915481567, -0.2969031035900116,
  0.49729400873184204, -0.3059382736682892, 0.4898521304130554,
  -0.7203274369239807, 0.47671565413475037, 0.1270948052406311,
  0.41028112173080444, 0.463035523891449 }, { -0.36017751693725586,
  -0.24474093317985535, 0.4741400182247162, -0.24970588088035583,
  0.5802808403968811, -0.7732722163200378, 0.5051204562187195,
  0.6651050448417664, 0.4411555230617523, 0.4398174285888672 }, {
  -0.09952408075332642, -0.22142039239406586, 0.505150318145752,
  -0.2818147540092468, 0.5554866194725037, -0.7599970102310181,
  0.4819079041481018, 0.46836376190185547, 0.4341869652271271,
  0.43512919545173645 }, { 0.5686147212982178, -0.18401777744293213,
  0.4294854998588562, -0.23842167854309082, 0.46184518933296204,
  -0.6931471228599548, 0.447188138961792, 0.42545783519744873,
  0.3808431625366211, 0.405420184135437 }, { 0.37540721893310547,
  -0.29956886172294617, 0.47791191935539246, -0.3045949935913086,
  0.45226752758026123, -0.6477946043014526, 0.4435006380081177,
  0.04529328644275665, 0.3958480656147003, 0.4403669238090515 }, {
  0.39132338762283325, -0.31595879793167114, 0.49054065346717834,
  -0.3178234398365021, 0.4703467786312103, -0.5904060006141663,
  0.45879489183425903, 0.02425980195403099, 0.4105776250362396,
  0.4531162977218628 }, { -0.006057941820472479, 0.006569928489625454,
  0.0015440979041159153, 0.0013556998455896974, 0.005920958239585161,
  0.00019130691362079233, 0.0015525295166298747, -0.07831747829914093,
  0.004157649353146553, 0.001713182544335723 }, { 0.015238759107887745,
  -0.012075832113623619, 0.019996659830212593, -0.013050640933215618,
  0.019533328711986542, 0.04019935429096222, 0.020779648795723915,
  -0.017803780734539032, 0.01775379851460457, 0.016923801973462105 }, {
  -0.00040881827590055764, 0.01769774593412876, -0.0030561434105038643,
  0.017618050798773766, -0.003441327251493931, -0.008425338193774223,
  -0.004319507163017988, -0.040901608765125275, -0.008085516281425953,
  -0.00901162438094616 }, { -0.006333544384688139, 0.0218157060444355,
  -0.009262368083000183, 0.02132960595190525, -0.0016303389566019177,
  -0.004398090299218893, -0.010243585333228111, -0.026997482404112816,
  -0.009616672061383724, -0.0112041300162673 }, { 0.0016361094312742352,
  0.003124030539765954, 0.002565001603215933, 0.0005618871073238552,
  0.006878560408949852, 0.03515741601586342, 0.0034865504130721092,
  -0.06985997408628464, 0.0033802350517362356, 0.004246413242071867 }, {
  0.0022312409710139036, -0.0017821462824940681, 0.020819153636693954,
  0.014220071956515312, 0.023876415565609932, 0.06832368671894073,
  0.021195560693740845, -0.054931141436100006, 0.018499089404940605,
  0.020361075177788734 }, { -0.0015170410042628646, 0.0030387609731405973,
  0.009525091387331486, 0.0023157033137977123, 0.012122565880417824,
  0.05290598422288895, 0.007844913750886917, -0.03350060060620308,
  0.007179108913987875, 0.007509269751608372 }, { 0.0026995691005140543,
  0.01033916138112545, 0.005106386262923479, 0.013446318916976452,
  0.017022928223013878, 0.029302654787898064, 0.0039514112286269665,
  -0.04868422821164131, 0.0026275364216417074, 0.0003789003530982882 }, {
  0.0017787649994716048, 0.0011385915568098426, 0.006451384164392948,
  -0.0025774631649255753, 0.00652729906141758, 0.04508327320218086,
  0.006555443163961172, -0.039301082491874695, 0.004885929170995951,
  0.005540152080357075 }, { 0.019082074984908104, -0.024626603350043297,
  0.03249650448560715, -0.024554960429668427, 0.034270841628313065,
  0.17475825548171997, 0.03194909542798996, -0.03408300504088402,
  0.031355202198028564, 0.03307552635669708 }, { -0.002374011091887951,
  0.011019104160368443, 0.00536889536306262, 0.009987344965338707,
  0.005368947982788086, 0.020124142989516258, 0.00080679333768785,
  -0.03276708722114563, -0.0007575554773211479, -0.0007960750954225659 }, {
  -0.004796746652573347, 0.022617409005761147, -0.006781514268368483,
  0.02012668177485466, -0.007941807620227337, -0.04676627740263939,
  -0.005258339922875166, -0.046246204525232315, -0.0071578314527869225,
  -0.009032237343490124 }, { 0.009770474396646023, -0.011141248978674412,
  0.019269749522209167, -0.014210346154868603, 0.020542146638035774,
  0.048880185931921005, 0.020035162568092346, -0.03952275589108467,
  0.01856170780956745, 0.018174735829234123 }, { -0.001620269613340497,
  0.011470676399767399, 0.004611546639353037, 0.006774203386157751,
  0.002739626681432128, 0.02218065969645977, 0.0017491821199655533,
  -0.03775838017463684, -0.000319438346195966, -0.0004950406146235764 }, {
  0.0012955022975802422, -0.014817631803452969, 0.026199808344244957,
  -0.016461731866002083, 0.026273394003510475, 0.01814219355583191,
  0.025083784013986588, -0.052376847714185715, 0.023744210600852966,
  0.02334190532565117 }, { -0.004868587013334036, 0.0016003461787477136,
  0.007678245659917593, 0.010228456929326057, 0.007693978026509285,
  0.03484954312443733, 0.006526602897793055, -0.04437534511089325,
  0.005023591686040163, 0.006007996853441 }, { 0.005454160738736391,
  -0.0013410535175353289, 0.018168626353144646, -0.0020983892027288675,
  0.015060464851558208, 0.03024686872959137, 0.015840236097574234,
  -0.04037412256002426, 0.011990564875304699, 0.013903414830565453 }, {
  0.032678719609975815, 0.029509004205465317, -0.010374271310865879,
  0.027847718447446823, -0.0037994948215782642, -0.005600559059530497,
  -0.011222416535019875, -0.04614663124084473, -0.011661309748888016,
  -0.01393105834722519 }, { -0.015608241781592369, 0.027740608900785446,
  -0.01684558019042015, 0.028051670640707016, -0.01144394464790821,
  -0.07844652235507965, -0.010136575438082218, 0.008260861039161682,
  -0.014186658896505833, -0.018748557195067406 }, { 0.002531855134293437,
  -0.0005372058367356658, 0.003925851080566645, -0.0011777161853387952,
  0.010105716064572334, 0.02006799913942814, 0.006369675975292921,
  -0.035407859832048416, 0.004390612710267305, 0.003906560130417347 }, {
  0.0004741567827295512, -0.005425834562629461, 0.013468168675899506,
  -0.007848411798477173, 0.014999646693468094, 0.05871981754899025,
  0.01284038182348013, -0.0707777887582779, 0.01137702725827694,
  0.011949912644922733 }, { 0.0034670683089643717, 0.015495876781642437,
  -0.0003862276498693973, 0.020269881933927536, 0.006256113760173321,
  -0.03999203070998192, -0.0016746723558753729, -0.016698412597179413,
  -0.004960658494383097, -0.00985676608979702 }, { 0.35677266120910645,
  -0.3067082464694977, 0.48919913172721863, -0.31237122416496277,
  0.4738852381706238, -0.5941600799560547, 0.4615767002105713,
  0.047763656824827194, 0.40800178050994873, 0.4500437378883362 }, {
  -0.25821566581726074, -0.22462493181228638, 0.4883313477039337,
  -0.24713778495788574, 0.5772050619125366, -0.7332009673118591,
  0.5216001868247986, 0.5480482578277588, 0.43185901641845703,
  0.4523636996746063 }, { 0.19879445433616638, -0.25711092352867126,
  0.4803866744041443, -0.2656075656414032, 0.5224763751029968,
  -0.6769493222236633, 0.48308855295181274, 0.3640625476837158,
  0.4015120565891266, 0.44193294644355774 }, { 0.17444361746311188,
  -0.28432539105415344, 0.5108065009117126, -0.29203298687934875,
  0.4814567267894745, -0.6813467741012573, 0.47634705901145935,
  0.17478255927562714, 0.4159505069255829, 0.471327543258667 }, {
  0.5217663645744324, -0.17899653315544128, 0.39776644110679626,
  -0.20610567927360535, 0.42632627487182617, -0.7954551577568054,
  0.42123308777809143, 0.4024495780467987, 0.33674800395965576,
  0.3868448734283447 }, { 0.31139451265335083, -0.26311445236206055,
  0.45686542987823486, -0.26005586981773376, 0.45263493061065674,
  -0.7277234792709351, 0.44414806365966797, 0.20275796949863434,
  0.3741361200809479, 0.4068785309791565 }, { 0.47839173674583435,
  -0.326466828584671, 0.5236772894859314, -0.3327166438102722,
  0.4952683448791504, -0.3960452973842621, 0.4910362958908081,
  0.03845810517668724, 0.43991318345069885, 0.4891665577888489 }, {
  0.5242507457733154, -0.24348242580890656, 0.4767012298107147,
  -0.27835455536842346, 0.5170917510986328, -0.5139406323432922,
  0.48506686091423035, 0.5183406472206116, 0.39156001806259155,
  0.416274756193161 }, { 0.5781201124191284, -0.1694248616695404,
  0.39874783158302307, -0.2267722487449646, 0.45742788910865784,
  -0.756742537021637, 0.43179264664649963, 0.5569558143615723,
  0.3354019820690155, 0.38277822732925415 }, { 0.44512343406677246,
  -0.28214940428733826, 0.45495280623435974, -0.2845173180103302,
  0.43727442622184753, -0.6208862066268921, 0.42300325632095337,
  0.05262891575694084, 0.37483906745910645, 0.4194048047065735 }, {
  0.5658515095710754, -0.24622099101543427, 0.40973880887031555,
  -0.25131961703300476, 0.4089406132698059, -0.7447801828384399,
  0.4004283547401428, 0.2017516791820526, 0.3478139638900757,
  0.38178232312202454 }, { 0.4014036953449249, -0.3180599808692932,
  0.4926551580429077, -0.3234487771987915, 0.4705946743488312,
  -0.5702056884765625, 0.4595737159252167, 0.0025559605564922094,
  0.4122040569782257, 0.4547051191329956 }, { 0.00631254818290472,
  0.004695649724453688, 0.001254465663805604, 0.005696732550859451,
  0.0023733554407954216, 0.04329599067568779, 0.0016458479221910238,
  -0.051247015595436096, 0.0024118819274008274, 0.0006495030829682946 }, {
  -0.0032856527250260115, -0.018718909472227097, 0.030709968879818916,
  -0.012741449289023876, 0.02889016829431057, 0.0657300055027008,
  0.027614576742053032, -0.035456832498311996, 0.0254605021327734,
  0.026815468445420265 }, { -0.003770829876884818, -0.0016013112617656589,
  0.010914111509919167, 0.0016578776994720101, 0.010670076124370098,
  0.039462439715862274, 0.010168864391744137, -0.05946071818470955,
  0.007895838469266891, 0.009147178381681442 }, { -0.006373136304318905,
  0.008666799403727055, 0.001952896942384541, 0.00739066069945693,
  0.002088198671117425, 0.037924543023109436, 0.0035334238782525063,
  -0.011865115724503994, 0.0002879906678572297, -0.001207929104566574 }, {
  -0.0007611983455717564, 0.0015425271121785045, 0.0051070027984678745,
  -0.0013066474348306656, 0.005959689617156982, 0.02223912440240383,
  0.007067907135933638, -0.024973992258310318, 0.003854858921840787,
  0.0060404338873922825 }, { 0.017561906948685646, -0.01144108735024929,
  0.018111426383256912, -0.012923494912683964, 0.019758738577365875,
  0.03190469369292259, 0.019775792956352234, -0.052073489874601364,
  0.018106823787093163, 0.016977809369564056 }, { -0.0050155650824308395,
  0.008771779015660286, 0.00379161792807281, 0.008968946523964405,
  0.005812218878418207, 0.02727273479104042, 0.0007583085680380464,
  -0.0533866211771965, -0.002516883658245206, 0.00009238173515768722 }, {
  -0.00247786077670753, 0.0003207485133316368, 0.016416607424616814,
  -0.002901908941566944, 0.015632500872015953, 0.04922391474246979,
  0.011707223020493984, -0.04018537700176239, 0.014558601193130016,
  0.013372098095715046 }, { -0.0006833462393842638, -0.008516350761055946,
  0.016746778041124344, -0.010095765814185143, 0.019341517239809036,
  0.07184676826000214, 0.01662410981953144, -0.0477169044315815,
  0.014878511428833008, 0.016003578901290894 }, { 0.006134988274425268,
  0.0028561220970004797, 0.006001178175210953, 0.0025067164096981287,
  0.0073916856199502945, -0.005343225318938494, 0.006808382924646139,
  -0.05429920181632042, 0.005704749375581741, 0.004888042341917753 }, {
  -0.008253844454884529, -0.012654522433876991, 0.030933868139982224,
  -0.017089130356907845, 0.030207190662622452, 0.05908428877592087,
  0.02486512064933777, -0.05387717857956886, 0.027740055695176125,
  0.027160899713635445 }, { -0.0030630494002252817, 0.03412308543920517,
  0.025218475610017776, 0.05634024739265442, 0.0145757757127285,
  0.03613355755805969, 0.017948228865861893, 0.0029273657128214836,
  0.019232898950576782, 0.025804951786994934 }, { -0.0053084841929376125,
  0.008004368282854557, 0.002490437123924494, 0.007242793682962656,
  0.002230247249826789, -0.005027027800679207, 0.0013848483795300126,
  -0.05966925993561745, 0.0007122044917196035, 0.0005953755462542176 }, {
  -0.003552465233951807, 0.01371860597282648, 0.00029682100284844637,
  0.014464018866419792, 0.006823183503001928, -0.0029436377808451653,
  0.0036627105437219143, -0.026593642309308052, 0.003319727722555399,
  -0.004079866223037243 }, { -0.004950231406837702, 0.009796304628252983,
  -0.005045390222221613, 0.010425612330436707, -0.0023220933508127928,
  0.0281475018709898, -0.00399128720164299, -0.059150245040655136,
  -0.0031713603530079126, -0.005205043125897646 }, { -0.009771433658897877,
  -0.0007495912723243237, 0.011543015018105507, 0.00681203231215477,
  0.011193306185305119, 0.056541558355093, 0.009296410717070103,
  -0.048109039664268494, 0.009890548884868622, 0.01428703498095274 }, {
  0.0004116710042580962, -0.00467436108738184, 0.010720730759203434,
  -0.0071477461606264114, 0.010865158401429653, 0.028416208922863007,
  0.01043710671365261, -0.05642630532383919, 0.009662536904215813,
  0.009986967779695988 }, { -0.00758307846263051, 0.0014912659535184503,
  0.01690526492893696, 0.004506679717451334, 0.013007068075239658,
  0.05443597212433815, 0.012869101949036121, -0.04848651587963104,
  0.013623030856251717, 0.01024931576102972 }, { -0.0021359408274292946,
  0.0019886293448507786, 0.0138174407184124, -0.0016140117077156901,
  0.016112633049488068, 0.03569406270980835, 0.013866663910448551,
  -0.06101948767900467, 0.012550893239676952, 0.008590311743319035 }, {
  -0.00042973129893653095, -0.0015992613043636084, 0.00973537378013134,
  -0.004072064533829689, 0.013309834524989128, 0.02134225331246853,
  0.01163671538233757, -0.04713080823421478, 0.01012404914945364,
  0.009876932948827744 }, { -0.011610781773924828, 0.014853764325380325,
  0.014632822014391422, 0.029135484248399734, 0.011313805356621742,
  0.003662638133391738, 0.015793537721037865, -0.03962944820523262,
  0.005145533941686153, 0.00009221830987371504 }, { 0.004347763489931822,
  0.022476281970739365, -0.01422419585287571, 0.023311611264944077,
  -0.008525911718606949, -0.018679389730095863, -0.01441978570073843,
  -0.050741516053676605, -0.012619998306035995, -0.016100144013762474 }, {
  0.26648804545402527, -0.24869973957538605, 0.5001082420349121,
  -0.26320508122444153, 0.5172261595726013, -0.600309431552887,
  0.4873872697353363, 0.3840385675430298, 0.4301820397377014,
  0.44938644766807556 }, { 0.19970428943634033, -0.24906688928604126,
  0.49419620633125305, -0.2521631419658661, 0.591415286064148,
  -0.6174148321151733, 0.4951655864715576, 0.5356807708740234,
  0.4415935277938843, 0.5007588267326355 }, { 0.45470723509788513,
  -0.21435604989528656, 0.4544687867164612, -0.24683958292007446,
  0.4703499674797058, -0.7032299637794495, 0.42703747749328613,
  0.3735293447971344, 0.3851105868816376, 0.4045441448688507 }, {
  0.23523642122745514, -0.280335396528244, 0.5114400386810303,
  -0.28569453954696655, 0.519293487071991, -0.6316213607788086,
  0.4714227318763733, 0.24102947115898132, 0.4118637144565582,
  0.4599464237689972 }, { -0.06750105321407318, -0.23893500864505768,
  0.5113561153411865, -0.25943517684936523, 0.5291240811347961,
  -0.8059202432632446, 0.4518407881259918, 0.559169590473175,
  0.3906984329223633, 0.42972540855407715 }, { -0.04944419860839844,
  -0.3194381892681122, 0.5327072739601135, -0.33172181248664856,
  0.5322365164756775, -0.6178959012031555, 0.4992518723011017,
  0.10273844748735428, 0.4417611062526703, 0.4914925992488861 }, {
  0.12261144071817398, -0.27961334586143494, 0.4897664785385132,
  -0.28379377722740173, 0.4701533615589142, -0.7701170444488525,
  0.4573203921318054, 0.13482007384300232, 0.4046354293823242,
  0.4424322843551636 }, { -0.12076657265424728, -0.26055288314819336,
  0.5143585801124573, -0.2957977056503296, 0.5377769470214844,
  -0.7055689096450806, 0.5118506550788879, 0.5443096160888672,
  0.42148810625076294, 0.49116748571395874 }, { 0.35388174653053284,
  -0.2781399190425873, 0.4809688925743103, -0.2846035659313202,
  0.4714585840702057, -0.6599823236465454, 0.4498941898345947,
  0.17147189378738403, 0.3920755982398987, 0.43900835514068604 }, {
  -0.0724145770072937, -0.298572301864624, 0.5292425155639648,
  -0.3123910129070282, 0.5187233686447144, -0.7006471157073975,
  0.4884525239467621, 0.1735648512840271, 0.4334541857242584,
  0.47951751947402954 }, { 0.49916213750839233, -0.22020630538463593,
  0.44710540771484375, -0.2740632891654968, 0.48884180188179016,
  -0.6627715826034546, 0.44638872146606445, 0.46793827414512634,
  0.3978542685508728, 0.4065893292427063 }, { -0.05901636928319931,
  -0.2896057069301605, 0.5240043997764587, -0.2961432933807373,
  0.5208248496055603, -0.6868585348129272, 0.49868494272232056,
  0.2699999511241913, 0.43201151490211487, 0.47376498579978943 }, {
  -0.002234352519735694, 0.016013534739613533, 0.002894036704674363,
  0.013280924409627914, 0.003373500658199191, -0.0045653413981199265,
  0.001402402762323618, -0.04343356192111969, 0.004746296443045139,
  -0.005772083532065153 }, { -0.003404085524380207, 0.019610367715358734,
  -0.006076980847865343, 0.02683728188276291, -0.004124600440263748,
  -0.042014770209789276, -0.0060096983797848225, -0.023686058819293976,
  -0.0037593937013298273, -0.011510312557220459 }, { 0.010586127638816833,
  -0.013853782787919044, 0.022643573582172394, -0.017112020403146744,
  0.023843154311180115, 0.06436611711978912, 0.023400604724884033,
  -0.03352835774421692, 0.02105114795267582, 0.021704377606511116 }, {
  0.012631593272089958, 0.01700655370950699, -0.010391277261078358,
  0.016881456598639488, -0.00943238940089941, 0.025502588599920273,
  -0.011467267759144306, -0.048643022775650024, -0.011530925519764423,
  -0.01087180431932211 }, { 0.0008400416118092835, -0.012132988311350346,
  0.02489103376865387, -0.014805002138018608, 0.024110503494739532,
  0.08459749817848206, 0.02301730029284954, -0.0426340289413929,
  0.021684782579541206, 0.022695453837513924 }, { -0.003004414727911353,
  0.01831796206533909, -0.00488548818975687, 0.0236123688519001,
  -0.0037792918737977743, -0.044561997056007385, -0.008535650558769703,
  -0.032742831856012344, -0.001632258528843522, -0.009045031853020191 }, {
  0.00023985032748896629, -0.0030061749275773764, 0.012408904731273651,
  -0.006272349040955305, 0.011873750016093254, 0.06629911810159683,
  0.011471881531178951, -0.05111151188611984, 0.010345963761210442,
  0.011247397400438786 }, { 0.0023007874842733145, 0.006500924937427044,
  0.010920364409685135, 0.006234305445104837, 0.011485299095511436,
  0.03967350348830223, 0.009669859893620014, -0.04745170846581459,
  0.011817275546491146, 0.010059949941933155 }, { 0.001465094625018537,
  -0.00048672384582459927, 0.0163226667791605, -0.001292944303713739,
  0.0151982381939888, 0.0606490895152092, 0.013637114316225052,
  -0.06261260062456131, 0.014055446721613407, 0.013576042838394642 }, {
  -0.0001873112632893026, 0.0015860183630138636, 0.003434687154367566,
  -0.00017216514970641583, 0.0029561116825789213, 0.018156403675675392,
  0.0027261353097856045, -0.04237988591194153, 0.00225082878023386,
  0.0024046837352216244 }, { -0.0026958626694977283, 0.009052198380231857,
  0.005014043767005205, 0.01248753722757101, 0.0035849723499268293,
  0.02170162834227085, 0.0008693770505487919, -0.06040492653846741,
  0.002804276766255498, 0.0051020486280322075 }, { 0.00942535512149334,
  -0.004300141241401434, 0.008385482244193554, -0.004852784797549248,
  0.011213487014174461, 0.018281737342476845, 0.011016284115612507,
  -0.038639508187770844, 0.008772789500653744, 0.007894097827374935 }, {
  0.0010291871149092913, -0.00981814879924059, 0.024387352168560028,
  -0.010375672951340675, 0.01893046498298645, 0.06595788896083832,
  0.01827145181596279, -0.0444631353020668, 0.016436178237199783,
  0.017636051401495934 }, { -0.010090198367834091, 0.008834106847643852,
  0.002184360520914197, 0.007961283437907696, 0.0010680037084966898,
  0.028744075447320938, -0.00012055880506522954, -0.04150494188070297,
  0.00022014508431311697, -0.00010875037696678191 }, { -0.002214360050857067,
  0.002061660634353757, 0.003913296386599541, 0.0011758452747017145,
  0.005529853515326977, 0.03328150138258934, 0.0036821728572249413,
  -0.06388077139854431, 0.003236079355701804, 0.0020536042284220457 }, {
  0.005336817819625139, -0.003152756718918681, 0.010073942132294178,
  -0.0028491178527474403, 0.011316847987473011, 0.04968370124697685,
  0.009736640378832817, -0.022268712520599365, 0.008456943556666374,
  0.009223775006830692 }, { 0.003610957181081176, 0.0018024005694314837,
  0.006994737312197685, 0.0003976915904786438, 0.006564057432115078,
  0.028843484818935394, 0.006228307727724314, -0.04193565621972084,
  0.004515984561294317, 0.0038089128211140633 }, { 0.0035793259739875793,
  0.00024845683947205544, 0.011646122671663761, -0.0006574213039129972,
  0.01175664085894823, 0.032858606427907944, 0.011057045310735703,
  -0.05352763459086418, 0.009176482446491718, 0.007683977019041777 }, {
  0.017327478155493736, -0.021014131605625153, 0.03675592318177223,
  -0.023575730621814728, 0.03674892336130142, 0.17082227766513824,
  0.03329358994960785, -0.06862113624811172, 0.035587064921855927,
  0.03224540501832962 }, { -0.0003742593398783356, -0.0007492642616853118,
  0.01074102334678173, 0.004762626253068447, 0.010435575619339943,
  0.05701477453112602, 0.008857154287397861, -0.04856060445308685,
  0.009517062455415726, 0.009449489414691925 }, { 0.021506890654563904,
  -0.004900256637483835, 0.013120364397764206, -0.004270331934094429,
  0.013063513673841953, 0.036737289279699326, 0.01273847185075283,
  -0.030944833531975746, 0.011892692185938358, 0.012283744290471077 }, {
  -0.0005700172041542828, 0.012877707369625568, -0.0023861911613494158,
  0.012297096662223339, 0.007443356327712536, 0.032988592982292175,
  -0.006841632537543774, -0.0522049181163311, -0.0029206429608166218,
  -0.005925927311182022 }, { 0.32971906661987305, -0.2569878399372101,
  0.5150460004806519, -0.25439950823783875, 0.6113936901092529,
  -0.48353490233421326, 0.5259202718734741, 0.5645553469657898,
  0.4593457877635956, 0.46227583289146423 }, { 0.37084445357322693,
  -0.20920789241790771, 0.45929017663002014, -0.260132759809494,
  0.47654494643211365, -0.742158055305481, 0.43023625016212463,
  0.4480195939540863, 0.38146743178367615, 0.41218599677085876 }, {
  -0.13799647986888885, -0.2610854506492615, 0.4780105650424957,
  -0.2924763262271881, 0.5766012668609619, -0.7103790640830994,
  0.5072041153907776, 0.5746259093284607, 0.42655065655708313,
  0.4908026456832886 }, { 0.2539712190628052, -0.273158997297287,
  0.5076822638511658, -0.2911801040172577, 0.5195984840393066,
  -0.5903722643852234, 0.49708008766174316, 0.25440511107444763,
  0.42723336815834045, 0.4804675579071045 }, { 0.4277496337890625,
  -0.2303372174501419, 0.4371229112148285, -0.22747065126895905,
  0.41435521841049194, -0.8005786538124084, 0.40467798709869385,
  0.22788158059120178, 0.34313827753067017, 0.3844327926635742 }, {
  -0.05193758383393288, -0.32405146956443787, 0.5210202932357788,
  -0.3333767056465149, 0.5091855525970459, -0.6626431345939636,
  0.5018999576568604, 0.12005914747714996, 0.4389205276966095,
  0.4834160804748535 }, { 0.3554810881614685, -0.27852216362953186,
  0.45156434178352356, -0.28202542662620544, 0.4282422959804535,
  -0.7150483131408691, 0.4183313548564911, 0.038397300988435745,
  0.3712427616119385, 0.4142305850982666 }, { 0.41701021790504456,
  -0.2574079632759094, 0.44315722584724426, -0.26499179005622864,
  0.4175316393375397, -0.6946894526481628, 0.407196044921875,
  0.11480291187763214, 0.36187565326690674, 0.40444374084472656 }, {
  0.49864259362220764, -0.24022161960601807, 0.4428102970123291,
  -0.26831868290901184, 0.49580544233322144, -0.6362045407295227,
  0.41864120960235596, 0.3392195403575897, 0.39018359780311584,
  0.4225161671638489 }, { 0.4728687107563019, -0.288887083530426,
  0.4623958170413971, -0.29381319880485535, 0.4627613127231598,
  -0.6314435005187988, 0.446813702583313, 0.157890185713768, 0.3954184353351593,
  0.436819463968277 }, { 0.7190647721290588, -0.20700779557228088,
  0.4109399616718292, -0.20049646496772766, 0.4552929699420929,
  -0.6912363767623901, 0.3867221176624298, 0.39670324325561523,
  0.36270585656166077, 0.36164742708206177 }, { 0.39509230852127075,
  -0.3203185796737671, 0.49347588419914246, -0.3236173093318939,
  0.47046801447868347, -0.587643027305603, 0.4603486657142639,
  0.019273223355412483, 0.41295307874679565, 0.45615461468696594 }, {
  0.0015107422368600965, -0.008111530914902687, 0.01403808407485485,
  -0.007661266718059778, 0.018967866897583008, 0.05385633558034897,
  0.01691502332687378, -0.05261307954788208, 0.017988597974181175,
  0.014358200132846832 }, { -0.003521962324157357, -0.0030430376064032316,
  0.01573706604540348, -0.004934822674840689, 0.015962257981300354,
  0.03217754885554314, 0.015031723305583, -0.04776114970445633,
  0.013775642961263657, 0.014163395389914513 }, { -0.00162152957636863,
  0.01031531672924757, 0.0025367580819875, 0.010885938070714474,
  0.0012719847727566957, 0.007090716157108545, 0.00349213695153594,
  -0.048895012587308884, 0.00009081598545890301, 0.0007498999475501478 }, {
  -0.005247785244137049, 0.013717358000576496, 0.0017076137010008097,
  0.011759471148252487, 0.006176077760756016, 0.03477432206273079,
  -0.00039399511297233403, -0.04536423832178116, -0.0024714532773941755,
  0.0065734791569411755 }, { -0.00886576622724533, 0.0015375255607068539,
  0.013791244477033615, -0.001750514260493219, 0.01292826421558857,
  0.05824657902121544, 0.007982349023222923, -0.03780524805188179,
  0.010814276523888111, 0.010736916214227676 }, { -0.009352477267384529,
  0.0023313374258577824, 0.004659546539187431, 0.0012798323296010494,
  0.009132716804742813, 0.03420717641711235, 0.00446666544303298,
  -0.04006955772638321, 0.005003183614462614, 0.003841248108074069 }, {
  0.01427305769175291, -0.015364369377493858, 0.026737773790955544,
  -0.016058186069130898, 0.03137701749801636, 0.13593988120555878,
  0.02650587633252144, -0.03361409902572632, 0.026142967864871025,
  0.026552049443125725 }, { -0.00013387583021540195, -0.01002851128578186,
  0.018820548430085182, -0.011509539559483528, 0.020002681761980057,
  0.06615198403596878, 0.01913979835808277, -0.04728790372610092,
  0.017776139080524445, 0.017894001677632332 }, { -0.0019412607653066516,
  -0.0018155045108869672, 0.00907590240240097, 0.00012895507097709924,
  0.008858051151037216, 0.04029446840286255, 0.010800599120557308,
  -0.050823770463466644, 0.009680962190032005, 0.006776850204914808 }, {
  0.004218680318444967, -0.0006653969758190215, 0.011195164173841476,
  0.0028215600177645683, 0.011957314796745777, 0.027502169832587242,
  0.009083712473511696, -0.04110126942396164, 0.010082284919917583,
  0.009515357203781605 }, { -0.010092077776789665, 0.0004374016134534031,
  0.00759620126336813, 0.0005942480638623238, 0.00704161124303937,
  0.06316915899515152, 0.005854485090821981, -0.052614759653806686,
  0.00454446068033576, 0.005376110319048166 }, { -0.009543361142277718,
  0.004790019243955612, 0.002699700416997075, 0.002880487125366926,
  0.0036820336245000362, 0.05957769602537155, 0.0025948784314095974,
  -0.03791522979736328, 0.004117514006793499, 0.0023839971981942654 }, {
  -0.003232921240851283, 0.00028455432038754225, 0.003735104575753212,
  0.0003304227429907769, 0.004987048450857401, 0.020830029621720314,
  0.004268736578524113, -0.03267630934715271, 0.0032730563543736935,
  0.0030928240157663822 }, { -0.007887831889092922, 0.01775304786860943,
  -0.010209411382675171, 0.01583942398428917, -0.00694592110812664,
  -0.04492638260126114, -0.009174861013889313, -0.04145486652851105,
  -0.00873994454741478, -0.011859103105962276 }, { -0.011508720926940441,
  -0.0008797270711511374, 0.012334436178207397, -0.002126268809661269,
  0.011760641820728779, 0.06561554968357086, 0.010725924745202065,
  -0.05713455379009247, 0.009644977748394012, 0.010311487130820751 }, {
  -0.0014114591758698225, -0.0013780308654531837, 0.009845906868577003,
  0.00019869966490659863, 0.012768428772687912, 0.015545024536550045,
  0.00971787516027689, -0.0343363881111145, 0.01124667376279831,
  0.007428389508277178 }, { -0.0019165310077369213, 0.015990756452083588,
  -0.003961917478591204, 0.01446043886244297, -0.0020961558911949396,
  -0.024069203063845634, -0.0009506303467787802, -0.026605797931551933,
  -0.004948863293975592, -0.005360433831810951 }, { -0.0009331670007668436,
  0.010439150966703892, 0.002033381722867489, 0.005976949818432331,
  0.0030609718523919582, -0.0152490409091115, 0.0022052470594644547,
  -0.02463957481086254, 0.0018451027572154999, 0.0016752344090491533 }, {
  -0.02421066164970398, 0.02548786997795105, -0.014983361586928368,
  0.02521836943924427, -0.01682799868285656, -0.07953552156686783,
  -0.018269795924425125, -0.015474652871489525, -0.018383121117949486,
  -0.01861703395843506 }, { -0.0022197780199348927, 0.0054593454115092754,
  0.012789066880941391, 0.0043558888137340546, 0.012382447719573975,
  0.033836692571640015, 0.008521873503923416, -0.05198455974459648,
  0.00327088451012969, 0.00403466634452343 }, { 0.0012469867942854762,
  0.000039742051740176976, 0.012675073929131031, 0.0071757473051548,
  0.010641961358487606, 0.03840821236371994, 0.008852503262460232,
  -0.0515020452439785, 0.00727095315232873, 0.007266306318342686 }, {
  0.0239836648106575, 0.022883733734488487, -0.009106436744332314,
  0.024731729179620743, -0.010678094811737537, -0.007750748656690121,
  -0.017125196754932404, -0.047901980578899384, -0.01314406655728817,
  -0.0152578828856349 }, { 0.2024650275707245, -0.2556355893611908,
  0.49706771969795227, -0.26546382904052734, 0.5170111656188965,
  -0.7027327418327332, 0.4737210273742676, 0.5158984661102295,
  0.4176698923110962, 0.45604848861694336 }, { 0.2511301040649414,
  -0.25669336318969727, 0.44285476207733154, -0.2640312612056732,
  0.43021368980407715, -0.7673763632774353, 0.41621434688568115,
  0.14666114747524261, 0.360414981842041, 0.4032975435256958 }, {
  -0.035878200083971024, -0.29932811856269836, 0.5200004577636719,
  -0.30275869369506836, 0.5039951801300049, -0.7101736664772034,
  0.4889015555381775, 0.15757746994495392, 0.43065378069877625,
  0.47586190700531006 }, { 0.42416346073150635, -0.284225195646286,
  0.4706224203109741, -0.28746193647384644, 0.44657576084136963,
  -0.6410810351371765, 0.43831899762153625, 0.10210704803466797,
  0.3875702917575836, 0.4324491322040558 }, { 0.3799944519996643,
  -0.23468098044395447, 0.43374767899513245, -0.24029609560966492,
  0.4265262484550476, -0.8125537037849426, 0.40513134002685547,
  0.23688483238220215, 0.35393282771110535, 0.39388179779052734 }, {
  0.5151740908622742, -0.23919852077960968, 0.454291433095932,
  -0.25200510025024414, 0.48922625184059143, -0.5916802883148193,
  0.46632474660873413, 0.33609893918037415, 0.3940261900424957,
  0.4241180121898651 }, { 0.31598159670829773, -0.2846437096595764,
  0.489607036113739, -0.2929103970527649, 0.4900318384170532,
  -0.5738467574119568, 0.4853067100048065, 0.20726218819618225,
  0.4131965935230255, 0.4621387720108032 }, { 0.17968030273914337,
  -0.3021254539489746, 0.5211050510406494, -0.30443263053894043,
  0.4841987192630768, -0.6259934902191162, 0.47785505652427673,
  0.09802400320768356, 0.42168256640434265, 0.47705498337745667 }, {
  -0.072822205722332, -0.26418083906173706, 0.5029717683792114,
  -0.273860901594162, 0.5238067507743835, -0.7305569648742676,
  0.47113296389579773, 0.3515421152114868, 0.404433935880661, 0.4439637362957001
  }, { 0.49909141659736633, -0.25807374715805054, 0.44910740852355957,
  -0.2690280079841614, 0.45146873593330383, -0.6549240946769714,
  0.44270578026771545, 0.14907193183898926, 0.3812515139579773,
  0.404631644487381 }, { 0.9451454281806946, -0.12172175943851471,
  0.35375872254371643, -0.12911345064640045, 0.4211767911911011,
  -0.7854087352752686, 0.4128362834453583, 0.7100168466567993,
  0.275394082069397, 0.2850882112979889 }, { 0.32620251178741455,
  -0.2837602496147156, 0.5272522568702698, -0.28859567642211914,
  0.5113046765327454, -0.5401381850242615, 0.48731696605682373,
  0.1767905354499817, 0.429871529340744, 0.4830949306488037 }, {
  0.0001034512824844569, 0.0014297087909653783, 0.007380022667348385,
  -0.0013273477088660002, 0.008180003613233566, 0.02884218655526638,
  0.006742201279848814, -0.04736163094639778, 0.0064711500890553,
  0.005683882161974907 }, { -0.0012720412341877818, 0.0017057316144928336,
  0.012861287221312523, 0.0008145716856233776, 0.012058421038091183,
  0.05043844133615494, 0.012121297419071198, -0.03895298019051552,
  0.010499618947505951, 0.00921549927443266 }, { -0.003398544155061245,
  0.007194585166871548, 0.006937784608453512, 0.007087428588420153,
  0.014601846225559711, 0.004313499666750431, 0.010342626832425594,
  -0.04732348024845123, 0.007367708720266819, 0.00476636691018939 }, {
  -0.00038893934106454253, -0.0054539781995117664, 0.017097998410463333,
  -0.0077361674048006535, 0.01611400954425335, 0.06385892629623413,
  0.01621103473007679, -0.05143913999199867, 0.014218196272850037,
  0.015829984098672867 }, { -0.0015569461975246668, -0.0004716807743534446,
  0.01386708952486515, -0.001851478940807283, 0.014144710265100002,
  0.058693777769804, 0.007606356870383024, -0.05040718987584114,
  0.0086852191016078, 0.006490609608590603 }, { -0.0008776353788562119,
  0.0025141597725450993, 0.00858901347965002, 0.00003631951767602004,
  0.007644773926585913, 0.030429380014538765, 0.007567201275378466,
  -0.04120470583438873, 0.006361702457070351, 0.007417372427880764 }, {
  -0.007474453654140234, 0.008329227566719055, -0.0014144275337457657,
  0.009105396457016468, -0.0017333802534267306, 0.03594202548265457,
  -0.00170602195430547, -0.0650184378027916, -0.0035165611188858747,
  -0.0012938230065628886 }, { -0.005699983797967434, 0.004849062766879797,
  0.008374503813683987, 0.0041782306507229805, 0.005268950015306473,
  0.003478845115751028, 0.005731129553169012, -0.03419240936636925,
  0.003018561750650406, 0.0041783456690609455 }, { 0.02009463682770729,
  0.02764892764389515, -0.017680699005723, 0.026912381872534752,
  -0.01412166841328144, -0.0250224769115448, -0.02268531359732151,
  -0.05545519292354584, -0.015660272911190987, -0.021383706480264664 }, {
  -0.005010075867176056, -0.002268025651574135, 0.011254868470132351,
  -0.0009375481167808175, 0.0089499456807971, 0.04841604456305504,
  0.009131637401878834, -0.044481053948402405, 0.00793182011693716,
  0.009038356132805347 }, { -0.00508113531395793, 0.002514268271625042,
  0.002993303118273616, 0.0018126214854419231, 0.008111991919577122,
  0.01890823058784008, 0.005373830441385508, -0.0427052341401577,
  0.004490814171731472, 0.002286323579028249 }, { -0.0007105849799700081,
  -0.0006577741005457938, 0.012885059230029583, -0.005983484908938408,
  0.01568477228283882, 0.041648004204034805, 0.013795964419841766,
  -0.04489719495177269, 0.013163908384740353, 0.010458777658641338 }, {
  0.003718580584973097, -0.004785879980772734, 0.017198089510202408,
  -0.0068361032754182816, 0.018540117889642715, 0.059733398258686066,
  0.018065281212329865, -0.034459616988897324, 0.013666990213096142,
  0.015126876533031464 }, { -0.0022624428384006023, 0.008888696320354939,
  0.007892398163676262, 0.012993923388421535, 0.003014610381796956,
  0.00876035075634718, -0.0007005254738032818, -0.05129927396774292,
  0.0011976168025285006, -0.00349798914976418 }, { -0.0020581118296831846,
  0.007179563399404287, 0.002437642542645335, 0.0070954617112874985,
  -0.00042830390157178044, 0.06703010201454163, 0.0006539201131090522,
  -0.05018097907304764, -0.0021458633709698915, -0.0021123839542269707 }, {
  -0.015272526070475578, 0.00923843588680029, 0.0026710068341344595,
  0.007502542342990637, 0.002589230891317129, 0.024879610165953636,
  0.0009149846737273037, -0.029469823464751244, 0.0011784625239670277,
  -0.0012270213337615132 }, { 0.0033333704341202974, -0.013977563008666039,
  0.019253617152571678, -0.012292261235415936, 0.019836261868476868,
  0.04821594059467316, 0.01946161314845085, -0.04534419998526573,
  0.01916733756661415, 0.019060125574469566 }, { 0.01414389070123434,
  -0.019738802686333656, 0.043368540704250336, -0.017700836062431335,
  0.037637174129486084, 0.1972360759973526, 0.036332279443740845,
  -0.03329158574342728, 0.04156399145722389, 0.039473552256822586 }, {
  -0.0024562107864767313, 0.005195387173444033, 0.005882758181542158,
  0.006527344696223736, 0.006949870381504297, 0.002454560250043869,
  0.00637483038008213, -0.05690411105751991, 0.002228259574621916,
  0.002057186560705304 }, { -0.002114897361025214, -0.004048052243888378,
  0.020294521003961563, -0.006519239861518145, 0.01701320894062519,
  0.047927163541316986, 0.015208413824439049, -0.039080459624528885,
  0.01596655696630478, 0.012692058458924294 }, { -0.0031728586181998253,
  -0.006308139767497778, 0.014073040336370468, -0.0076532019302248955,
  0.014445527456700802, 0.060555350035429, 0.012900394387543201,
  -0.04208141565322876, 0.011637561023235321, 0.012679635547101498 }, {
  -0.003142057452350855, -0.0034169128630310297, 0.009995733387768269,
  0.0040106694214046, 0.011664467863738537, 0.04288806766271591,
  0.012626497074961662, -0.035296183079481125, 0.008529572747647762,
  0.00935597624629736 }, { 0.4980035126209259, -0.2097456455230713,
  0.4284243881702423, -0.19634218513965607, 0.4643947184085846,
  -0.7277891635894775, 0.42098382115364075, 0.4525802433490753,
  0.34272322058677673, 0.36339765787124634 }, { 0.37171104550361633,
  -0.2734377086162567, 0.4560849070549011, -0.2769210636615753,
  0.4302436411380768, -0.7394245266914368, 0.4212239980697632,
  0.06778233498334885, 0.3737483620643616, 0.41849958896636963 }, {
  0.14315171539783478, -0.33280885219573975, 0.5282275676727295,
  -0.33608922362327576, 0.5097172260284424, -0.5935012698173523,
  0.49451935291290283, 0.027227789163589478, 0.4386059045791626,
  0.4863540828227997 }, { 0.39705657958984375, -0.3159700930118561,
  0.489080011844635, -0.3196788430213928, 0.4660041332244873,
  -0.5700941681861877, 0.456408828496933, 0.00902116671204567,
  0.40913039445877075, 0.4516433775424957 }, { -0.05363082513213158,
  -0.2923521101474762, 0.527229368686676, -0.31503698229789734,
  0.5346335768699646, -0.6469199657440186, 0.5115681290626526,
  0.22393152117729187, 0.45344555377960205, 0.4775262773036957 }, {
  -0.2058877944946289, -0.20928259193897247, 0.48974913358688354,
  -0.2633398175239563, 0.5812196135520935, -0.7458516359329224,
  0.5018584132194519, 0.8229286074638367, 0.40985649824142456,
  0.47616511583328247 }, { -0.03551383689045906, -0.294028639793396,
  0.5143598914146423, -0.2975674271583557, 0.5005382299423218,
  -0.7268581986427307, 0.4848017990589142, 0.16768774390220642,
  0.4265562891960144, 0.4712880551815033 }, { 0.07675863057374954,
  -0.2376459538936615, 0.5038663744926453, -0.21692903339862823,
  0.5103217959403992, -0.7743855714797974, 0.4897463023662567,
  0.5830397009849548, 0.41292136907577515, 0.4403582215309143 }, {
  0.38198336958885193, -0.30988505482673645, 0.49205297231674194,
  -0.3137170970439911, 0.4636269509792328, -0.5859404802322388,
  0.45566508173942566, 0.034200482070446014, 0.4076629877090454,
  0.45405641198158264 }, { 0.6943585872650146, -0.2162187397480011,
  0.415563702583313, -0.21747009456157684, 0.4811369776725769,
  -0.6374079585075378, 0.45303553342819214, 0.5088182687759399,
  0.3500761091709137, 0.38261595368385315 }, { 0.4866848886013031,
  -0.19974316656589508, 0.43205076456069946, -0.2500990033149719,
  0.5082396864891052, -0.6846417784690857, 0.4276694357395172,
  0.4790182113647461, 0.39519038796424866, 0.41071170568466187 }, {
  -0.13120195269584656, -0.28756099939346313, 0.506804883480072,
  -0.29273855686187744, 0.5201780796051025, -0.7256585359573364,
  0.4998188614845276, 0.23331651091575623, 0.420910507440567,
  0.46347561478614807 }, { 0.020263617858290672, -0.02398751862347126,
  0.031117049977183342, -0.026444517076015472, 0.033532917499542236,
  0.15016087889671326, 0.031977180391550064, -0.022426113486289978,
  0.032213244587183, 0.031215893104672432 }, { 0.00016303094162140042,
  -0.0005079557886347175, 0.008175727911293507, -0.003915916197001934,
  0.008960898965597153, 0.027809739112854004, 0.0070376042276620865,
  -0.032052360475063324, 0.006963090039789677, 0.006496068090200424 }, {
  0.0015253173187375069, 0.014777729287743568, -0.0019750716164708138,
  0.013338723219931126, 0.0002951306232716888, -0.00804287288337946,
  -0.0028200107626616955, -0.05147448182106018, -0.003235999494791031,
  -0.006361926905810833 }, { -0.00026068519218824804, 0.007341846823692322,
  0.00494029326364398, 0.007645924109965563, 0.006241479888558388,
  0.012532778084278107, 0.0023908554576337337, -0.047997087240219116,
  0.0019561871886253357, 0.003923457581549883 }, { 0.0055681257508695126,
  -0.0065895807929337025, 0.019353939220309258, -0.0072127473540604115,
  0.02609376609325409, -0.007900835946202278, 0.019326237961649895,
  -0.06654947251081467, 0.016001546755433083, 0.016774775460362434 }, {
  -0.004201805684715509, 0.002335949568077922, 0.004686316009610891,
  0.000633189280051738, 0.007542524952441454, 0.05224112421274185,
  0.006588107440620661, -0.04902205243706703, 0.006768723484128714,
  0.003934974316507578 }, { -0.005735934246331453, -0.002975957468152046,
  0.014403949491679668, -0.0026752986013889313, 0.01753624528646469,
  0.06800984591245651, 0.01723332889378071, -0.03963148593902588,
  0.015854639932513237, 0.012425081804394722 }, { -0.004707885440438986,
  0.011655726470053196, -0.000299384439131245, 0.015042067505419254,
  -0.0007629760657437146, -0.022438373416662216, -0.0022332409862428904,
  -0.051876358687877655, -0.0005419617518782616, -0.005716115701943636 }, {
  0.004690894391387701, 0.004863144364207983, 0.00782408844679594,
  0.007873046211898327, 0.008985517546534538, 0.01980200596153736,
  0.007053704001009464, -0.01914944313466549, 0.005738165695220232,
  0.0047444868832826614 }, { 0.0014098609099164605, -0.0003986054507549852,
  0.007087371312081814, -0.00028210325399413705, 0.009423747658729553,
  0.029143216088414192, 0.008709214627742767, -0.036258161067962646,
  0.005485150497406721, 0.006132291629910469 }, { 0.008434508927166462,
  0.005169567186385393, 0.006516270339488983, 0.002090160036459565,
  0.0064424509182572365, 0.033114708960056305, 0.004466255195438862,
  -0.03761342167854309, 0.0021806969307363033, 0.0026210618671029806 }, {
  -0.0008251544204540551, 0.005243905819952488, 0.0063179307617247105,
  0.010176618583500385, 0.006117727607488632, 0.059992752969264984,
  0.004373328760266304, -0.045534078031778336, 0.0033736361656337976,
  0.0038741719909012318 }, { -0.0018498452845960855, 0.0011218012077733874,
  0.0035896305926144123, 0.00786408968269825, 0.010716152377426624,
  0.01770993135869503, 0.004966005217283964, -0.03396230936050415,
  0.00418362021446228, 0.0032204908784478903 }, { 0.005331010557711124,
  -0.007274183910340071, 0.019492829218506813, -0.007708560675382614,
  0.018325237557291985, 0.021840400993824005, 0.01857992447912693,
  -0.05069852992892265, 0.015546310693025589, 0.017652282491326332 }, {
  0.0061551243998110294, -0.0067198751494288445, 0.01217375136911869,
  -0.0038776465225964785, 0.015730099752545357, 0.04559868574142456,
  0.013174815103411674, -0.04056819900870323, 0.012913263402879238,
  0.011467943899333477 }, { -0.005125180818140507, 0.00437471829354763,
  0.011322085745632648, -0.0009740858804434538, 0.010905669070780277,
  0.042331743985414505, 0.007754409685730934, -0.03777961805462837,
  0.008502025157213211, 0.008063827641308308 }, { 0.00009201361535815522,
  -0.00939862709492445, 0.01751229353249073, -0.00897576566785574,
  0.016598859801888466, 0.04656074941158295, 0.017772328108549118,
  -0.04154404252767563, 0.015240632928907871, 0.014678829349577427 }, {
  0.0034175082109868526, -0.006245067343115807, 0.01799560897052288,
  -0.007359115872532129, 0.017865080386400223, 0.09320395439863205,
  0.01875576376914978, -0.05601831153035164, 0.014776765368878841,
  0.017442749813199043 }, { 0.0344444215297699, 0.015497531741857529,
  -0.004650880116969347, 0.012920305132865906, -0.0033617683220654726,
  0.009689759463071823, -0.0060478332452476025, -0.054280441254377365,
  -0.005980691406875849, -0.006819257978349924 }, { -0.0016789792571216822,
  0.017763644456863403, -0.011233877390623093, 0.01623489335179329,
  -0.004851062782108784, -0.033496346324682236, -0.005862857215106487,
  -0.020943569019436836, -0.01264400128275156, -0.012615418061614037 }, {
  0.0032434293534606695, -0.002535657724365592, 0.016603417694568634,
  -0.0011759568005800247, 0.016816364601254463, 0.05420137941837311,
  0.011708744801580906, -0.03238052502274513, 0.010250696912407875,
  0.01224898174405098 }, { -0.010468143969774246, 0.006247559562325478,
  0.000442272488726303, 0.005198853090405464, 0.001934064901433885,
  0.06291567534208298, 0.00007925542013254017, -0.049085527658462524,
  0.00014641298912465572, -0.000234912644373253 }, { 0.05748433992266655,
  -0.3004145622253418, 0.5059400796890259, -0.3048456907272339,
  0.48982006311416626, -0.7122836709022522, 0.4675930142402649,
  0.10337714105844498, 0.4189482033252716, 0.4583773612976074 }, {
  0.2314625382423401, -0.28387755155563354, 0.48159700632095337,
  -0.2916921079158783, 0.49806106090545654, -0.6411739587783813,
  0.4746934473514557, 0.21576014161109924, 0.43059784173965454,
  0.4659345746040344 }, { 0.7322643399238586, -0.17596033215522766,
  0.40273377299308777, -0.21373124420642853, 0.4535852074623108,
  -0.6836487054824829, 0.40143248438835144, 0.46859216690063477,
  0.3652418851852417, 0.3740067481994629 }, { 0.5762629508972168,
  -0.21222488582134247, 0.4420599937438965, -0.2340168058872223,
  0.46325451135635376, -0.6806350946426392, 0.40162724256515503,
  0.35366183519363403, 0.3584599196910858, 0.38596633076667786 }, {
  0.4814559817314148, -0.284950852394104, 0.4941795766353607,
  -0.2858513593673706, 0.4752497971057892, -0.5404026508331299,
  0.4468853771686554, 0.13097383081912994, 0.4004047214984894,
  0.4461156129837036 }, { 0.46920904517173767, -0.22464995086193085,
  0.41227978467941284, -0.22737666964530945, 0.4354296326637268,
  -0.7572371363639832, 0.40751829743385315, 0.26966050267219543,
  0.3621707558631897, 0.37370315194129944 }, { 0.4001244306564331,
  -0.3015642464160919, 0.4823078513145447, -0.30654510855674744,
  0.4531826376914978, -0.6341028213500977, 0.4467841386795044,
  0.07889309525489807, 0.4005136489868164, 0.44535648822784424 }, {
  0.08536136895418167, -0.2894590497016907, 0.5369172096252441,
  -0.2975267767906189, 0.5423058271408081, -0.6058066487312317,
  0.5260575413703918, 0.10728677362203598, 0.4588721990585327,
  0.4774160385131836 }, { -0.156595841050148, -0.3079659342765808,
  0.5159251093864441, -0.30142104625701904, 0.5428873300552368,
  -0.6842026114463806, 0.48538678884506226, 0.27556174993515015,
  0.4482533633708954, 0.48419129848480225 }, { -0.16680443286895752,
  -0.2451428771018982, 0.48644188046455383, -0.26209893822669983,
  0.5361882448196411, -0.7496296763420105, 0.4787711501121521,
  0.4982735216617584, 0.4359911382198334, 0.44098228216171265 }, {
  -0.0635901391506195, -0.2188900113105774, 0.47698721289634705,
  -0.2903880774974823, 0.5613070130348206, -0.7348792552947998,
  0.4638911187648773, 0.6031451225280762, 0.46169912815093994,
  0.48178136348724365 }, { -0.10117660462856293, -0.24561303853988647,
  0.5169081687927246, -0.2897927761077881, 0.5870382189750671,
  -0.6910725831985474, 0.5089510679244995, 0.7973889708518982,
  0.4971103370189667, 0.48363053798675537 }, { -0.0006422133301384747,
  0.00699690543115139, 0.014983654953539371, 0.0058754812926054,
  0.013354708440601826, 0.06260710954666138, 0.01104094460606575,
  -0.023850157856941223, 0.008996900171041489, 0.006454320624470711 }, {
  0.002674293937161565, 0.009830446913838387, 0.015991022810339928,
  0.01222702581435442, 0.015490354970097542, 0.023672504350543022,
  0.008879203349351883, -0.07357189059257507, 0.011916869319975376,
  0.008848906494677067 }, { -0.00005529536429094151, -0.009714844636619091,
  0.019512873142957687, -0.01219360064715147, 0.01873214729130268,
  0.08420958369970322, 0.017481638118624687, -0.04416817054152489,
  0.015729544684290886, 0.018113337457180023 }, { -0.0029804545920342207,
  -0.004589577671140432, 0.011460436508059502, -0.006201551295816898,
  0.01042337715625763, 0.06430846452713013, 0.010064974427223206,
  -0.05466027185320854, 0.008933083154261112, 0.010309524834156036 }, {
  0.004409444518387318, -0.011415109038352966, 0.01625971682369709,
  -0.009612435474991798, 0.01705070026218891, 0.03511267527937889,
  0.015850914642214775, -0.03921475261449814, 0.015634892508387566,
  0.015604815445840359 }, { 0.002096987795084715, 0.0020931647159159184,
  0.007141382899135351, -0.001340491813607514, 0.009163721464574337,
  0.02456776425242424, 0.0063947574235498905, -0.03222661837935448,
  0.006288853473961353, 0.0050973747856915 }, { -0.0034607239067554474,
  0.0031061512418091297, 0.007416469044983387, 0.0017525834264233708,
  0.008035082370042801, 0.01825927197933197, 0.0045385961420834064,
  -0.04628309607505798, 0.0050338017754256725, 0.0031098295003175735 }, {
  0.013295140117406845, -0.003324859542772174, 0.025390343740582466,
  -0.003924305085092783, 0.024210220202803612, 0.12190306931734085,
  0.0170985609292984, -0.03308294713497162, 0.02225038781762123,
  0.018125852569937706 }, { -0.0016678980318829417, -0.009337554685771465,
  0.019568176940083504, -0.012291750870645046, 0.0189657062292099,
  0.07632237672805786, 0.017948711290955544, -0.037182725965976715,
  0.017455358058214188, 0.017933927476406097 }, { 0.00018495075346436352,
  -0.0010653747012838721, 0.022742940112948418, -0.0031456167344003916,
  0.02321663126349449, 0.028897395357489586, 0.02606729231774807,
  -0.07048308104276657, 0.024645140394568443, 0.016696888953447342 }, {
  -0.001072198385372758, -0.0007396471919491887, 0.005770928226411343,
  0.0016552715096622705, 0.012147405184805393, 0.01228863000869751,
  0.008740259334445, -0.03436771035194397, 0.010297732427716255,
  0.00726251071318984 }, { 0.0010710692731663585, 0.0055290148593485355,
  0.006929269526153803, 0.005556853488087654, 0.008267863653600216,
  0.01496707834303379, 0.0055410549975931644, -0.0410819835960865,
  0.004156499169766903, 0.005045691505074501 }, { -0.0021238874178379774,
  0.002472770633175969, 0.006283507216721773, 0.0013875107979401946,
  0.007113832980394363, 0.049724988639354706, 0.006209261249750853,
  -0.020033443346619606, 0.004309189040213823, 0.006459884811192751 }, {
  -0.0007124415715225041, -0.0051717753522098064, 0.019124837592244148,
  -0.008177341893315315, 0.016783403232693672, 0.04223710671067238,
  0.016251731663942337, -0.027300149202346802, 0.016289258375763893,
  0.016962839290499687 }, { 0.0002419629308860749, 0.005653316155076027,
  0.004878369625657797, 0.004544268362224102, 0.004747139755636454,
  0.03066272847354412, 0.0033675977028906345, -0.05165494233369827,
  0.004021954722702503, 0.0050241099670529366 }, { -0.002074574586004019,
  -0.006678820587694645, 0.013416794128715992, -0.008097994141280651,
  0.012509034015238285, 0.056994061917066574, 0.01235214900225401,
  -0.025026755407452583, 0.010967383161187172, 0.012180999852716923 }, {
  -0.00021187332458794117, 0.009081171825528145, 0.007899428717792034,
  0.010133710689842701, 0.012805720791220665, 0.023471936583518982,
  0.007391876075416803, -0.03661924600601196, 0.01448797807097435,
  0.004828270059078932 }, { 0.001572385081090033, -0.025635521858930588,
  0.03550581634044647, -0.026116903871297836, 0.037323515862226486,
  0.08619633316993713, 0.034845370799303055, -0.04712314531207085,
  0.03374631330370903, 0.03381635621190071 }, { -0.0030969076324254274,
  0.0004503595409914851, 0.003994464408606291, 0.003491645911708474,
  0.004688626155257225, 0.013733210042119026, 0.0038224176969379187,
  -0.03556334972381592, 0.0028728488832712173, 0.0029469686560332775 }, {
  0.0016221802216023207, -0.003193127689883113, 0.011608647182583809,
  -0.005559929180890322, 0.011751323938369751, 0.03608258068561554,
  0.01324139628559351, -0.06177749112248421, 0.010341217741370201,
  0.007959919981658459 }, { -0.0056099239736795425, 0.00918140634894371,
  -0.00039480862324126065, 0.0061620320193469524, 0.0016795031260699034,
  0.03773985803127289, -0.0009877195116132498, -0.03919967636466026,
  -0.0007461411296389997, -0.0016115568578243256 }, { -0.004253915976732969,
  0.009847749955952168, 0.0019563166424632072, 0.008787315338850021,
  0.0008667649817653, 0.0035813958384096622, -0.0017758094472810626,
  -0.06278850138187408, 0.00138835737016052, -0.0003129424585495144 }, {
  -0.17939598858356476, -0.27844536304473877, 0.5212129950523376,
  -0.2902967631816864, 0.5039370656013489, -0.7545657753944397,
  0.4726392924785614, 0.2642815411090851, 0.4239436089992523,
  0.46291080117225647 }, { 0.48849835991859436, -0.25973615050315857,
  0.4468657374382019, -0.2647654116153717, 0.41828009486198425,
  -0.7162700891494751, 0.41093844175338745, 0.10013245046138763,
  0.36440014839172363, 0.40974563360214233 }, { -0.10971822589635849,
  -0.2990286350250244, 0.5397084355354309, -0.3039056360721588,
  0.5164146423339844, -0.6814507842063904, 0.4951390027999878,
  0.18886838853359222, 0.4410306215286255, 0.48860231041908264 }, {
  -0.09862486273050308, -0.24673829972743988, 0.5097599029541016,
  -0.2972269356250763, 0.5496587753295898, -0.6951537728309631,
  0.5087418556213379, 0.4584609568119049, 0.444987952709198, 0.4812290668487549
  }, { -0.04779630899429321, -0.1991073191165924, 0.5410584211349487,
  -0.27704566717147827, 0.5572314262390137, -0.7326679229736328,
  0.47875553369522095, 0.6717023253440857, 0.42449116706848145,
  0.4990275800228119 }, { 0.23070257902145386, -0.2908032536506653,
  0.5089505910873413, -0.31453976035118103, 0.5173734426498413,
  -0.569523274898529, 0.4894070327281952, 0.16679716110229492,
  0.4274459779262543, 0.4572615623474121 }, { -0.11214735358953476,
  -0.2869555652141571, 0.48671823740005493, -0.292818158864975,
  0.47493404150009155, -0.7705704569816589, 0.45869484543800354,
  0.16960425674915314, 0.40393802523612976, 0.45179077982902527 }, {
  -0.22548624873161316, -0.2387329339981079, 0.5436649918556213,
  -0.30128592252731323, 0.5553328990936279, -0.7291233539581299,
  0.4743258059024811, 0.3924575448036194, 0.46738868951797485,
  0.4971018433570862 }, { -0.14675763249397278, -0.2945316433906555,
  0.5314000248908997, -0.29357045888900757, 0.5400947332382202,
  -0.6586063504219055, 0.49865207076072693, 0.25670352578163147,
  0.43785858154296875, 0.5069266557693481 }, { 0.4656718373298645,
  -0.2801032066345215, 0.47092965245246887, -0.28259119391441345,
  0.43876153230667114, -0.6427084803581238, 0.4324922561645508,
  0.12260568886995316, 0.3862890601158142, 0.4358588755130768 }, {
  -0.2243649661540985, -0.2728715240955353, 0.5265766382217407,
  -0.3175083100795746, 0.5416776537895203, -0.6470391750335693,
  0.5048414468765259, 0.3777300715446472, 0.4433270990848541, 0.5132767558097839
  }, { 0.42592954635620117, -0.2556743621826172, 0.4496026337146759,
  -0.2635961174964905, 0.4339139461517334, -0.6852652430534363,
  0.4187034070491791, 0.1403844654560089, 0.37034907937049866,
  0.40996524691581726 }, { 0.006349429953843355, 0.008758490905165672,
  0.0024025600869208574, 0.0074418410658836365, 0.0068122586235404015,
  0.004567309282720089, 0.0041856649331748486, -0.03593219816684723,
  0.005340238101780415, 0.007625584956258535 }, { 0.00992648396641016,
  0.027865136042237282, -0.013052484951913357, 0.03475460037589073,
  -0.009106453508138657, -0.059478554874658585, -0.012555109336972237,
  -0.04875533655285835, -0.013867026194930077, -0.016776222735643387 }, {
  -0.00919875968247652, 0.0077290842309594154, 0.0029145595617592335,
  0.006386174354702234, 0.0050420681945979595, 0.035884469747543335,
  0.0023514979984611273, -0.026723366230726242, 0.0033713094890117645,
  0.0022858516313135624 }, { 0.003402372822165489, -0.0050055356696248055,
  0.010922269895672798, -0.004661293234676123, 0.010839125141501427,
  0.07475539296865463, 0.010319668799638748, -0.049569301307201385,
  0.008867098018527031, 0.010002100840210915 }, { 0.0034308244939893484,
  -0.00010209958418272436, 0.009724345058202744, -0.0040523274801671505,
  0.009339124895632267, 0.0765046626329422, 0.008690908551216125,
  -0.05033581331372261, 0.007238353602588177, 0.008703971281647682 }, {
  0.00016939315537456423, 0.0036689804401248693, 0.005852220114320517,
  0.003966270945966244, 0.007253644056618214, 0.012695081532001495,
  0.004334104247391224, -0.0486932173371315, 0.005126115400344133,
  0.001781611004844308 }, { 0.00617396691814065, 0.01146733295172453,
  -0.005833564791828394, 0.011826511472463608, -0.00216634850949049,
  -0.02159707434475422, -0.0027919351123273373, -0.06520309299230576,
  -0.0035587691236287355, -0.007957630790770054 }, { 0.0008262136834673584,
  0.004355533979833126, 0.0018761655082926154, 0.005150128155946732,
  0.002988312393426895, 0.01281831320375204, 0.0016794330440461636,
  -0.0390508808195591, 0.0013916873140260577, 0.0001941779482876882 }, {
  -0.00004851054472965188, -0.01201767660677433, 0.024829553440213203,
  -0.008297210559248924, 0.026100557297468185, 0.043741077184677124,
  0.02266228385269642, -0.048086125403642654, 0.02307322807610035,
  0.02412465587258339 }, { -0.0011748506221920252, 0.0014962955610826612,
  0.006020717788487673, 0.0034769370686262846, 0.010606036521494389,
  0.031417302787303925, 0.005139397922903299, -0.04918951168656349,
  0.006018136627972126, 0.00755356065928936 }, { 0.00022752655786462128,
  -0.0024958455469459295, 0.0104898102581501, -0.0035057987552136183,
  0.01983889751136303, 0.06993480771780014, 0.01040184311568737,
  -0.054011836647987366, 0.00848767627030611, 0.009434795938432217 }, {
  -0.01137248333543539, 0.019169019535183907, -0.005699540488421917,
  0.020259737968444824, -0.009858974255621433, -0.05176264047622681,
  -0.012346201576292515, -0.0015207919059321284, -0.010896929539740086,
  -0.013632716611027718 }, { 0.019687844440340996, -0.016997911036014557,
  0.04152873158454895, -0.01771809533238411, 0.04080713540315628,
  0.198679119348526, 0.04447152093052864, -0.05112702026963234,
  0.03946048393845558, 0.03607768565416336 }, { 0.00005108291588840075,
  -0.007710771635174751, 0.01803247258067131, -0.0069360146299004555,
  0.019745295867323875, 0.056591834872961044, 0.014080281369388103,
  -0.05748939514160156, 0.015569544397294521, 0.015056119300425053 }, {
  0.0063628265634179115, -0.005078371148556471, 0.020405638962984085,
  -0.00865379348397255, 0.02197723090648651, 0.06078439950942993,
  0.022219959646463394, -0.05925067141652107, 0.01677227020263672,
  0.017973273992538452 }, { 0.002265959745272994, -0.0022392929531633854,
  0.013171348720788956, -0.0039203274063766, 0.014817837625741959,
  0.02926689386367798, 0.011932063847780228, -0.047607481479644775,
  0.010706663131713867, 0.011735614389181137 }, { 0.0014648373471572995,
  0.0036698412150144577, 0.007382333278656006, 0.004113280214369297,
  0.008649623952805996, 0.045254651457071304, 0.0027535564731806517,
  -0.06927894800901413, 0.006338451988995075, 0.007019430864602327 }, {
  0.00044056089245714247, -0.010283137671649456, 0.01905573159456253,
  -0.013132072985172272, 0.01779758930206299, 0.06923307478427887,
  0.0174750704318285, -0.04245254769921303, 0.01608343794941902,
  0.01723497360944748 }, { -0.00034060439793393016, 0.0032564448192715645,
  0.011709870770573616, -0.0013793004909530282, 0.012723761610686779,
  0.04533017426729202, 0.010787508450448513, -0.05386055260896683,
  0.009837791323661804, 0.007716013118624687 }, { 0.006440089549869299,
  -0.004935078322887421, 0.016215354204177856, -0.005261401180177927,
  0.013468231074512005, 0.04748852923512459, 0.01386487577110529,
  -0.023055989295244217, 0.01248460728675127, 0.012813093140721321 }, {
  0.0024100805167108774, 0.003949601203203201, 0.013426079414784908,
  0.003418722888454795, 0.009464995004236698, 0.00673643359914422,
  0.007718656212091446, -0.0340745709836483, 0.005984948016703129,
  0.004742426332086325 }, { -0.0006950328242965043, -0.009912993758916855,
  0.01731671206653118, -0.009677963331341743, 0.017950914800167084,
  0.04394759237766266, 0.015702784061431885, -0.039462897926568985,
  0.014503180049359798, 0.015180781483650208 }, { -0.12449537962675095,
  -0.2796618640422821, 0.5373491644859314, -0.3040497601032257,
  0.548844039440155, -0.6404352188110352, 0.5001888275146484,
  0.3734420835971832, 0.45425084233283997, 0.5000465512275696 }, {
  0.4505344033241272, -0.2586415410041809, 0.44793030619621277,
  -0.2633204162120819, 0.43474504351615906, -0.7237627506256104,
  0.4105754792690277, 0.1324867159128189, 0.3643965423107147, 0.407732218503952
  }, { 0.3970632255077362, -0.3023785352706909, 0.48028749227523804,
  -0.30594387650489807, 0.45442909002304077, -0.5986360907554626,
  0.44578656554222107, 0.05206897482275963, 0.39808422327041626,
  0.4438410699367523 }, { 0.45537206530570984, -0.27713721990585327,
  0.47015684843063354, -0.2807360291481018, 0.44025346636772156,
  -0.6490985155105591, 0.4320252239704132, 0.09027732908725739,
  0.3839702606201172, 0.429051011800766 }, { 0.3831164836883545,
  -0.2999071180820465, 0.47874411940574646, -0.3052879571914673,
  0.45563340187072754, -0.6477287411689758, 0.4443303644657135,
  0.05708439648151398, 0.3995322585105896, 0.44064900279045105 }, {
  -0.16495628654956818, -0.2562197148799896, 0.514265775680542,
  -0.27941155433654785, 0.5780549645423889, -0.7235912680625916,
  0.49422237277030945, 0.699141800403595, 0.41885998845100403,
  0.45819440484046936 }, { -0.24704083800315857, -0.22255827486515045,
  0.5046676993370056, -0.31884849071502686, 0.5316600799560547,
  -0.7154296636581421, 0.5253787040710449, 0.5879004001617432,
  0.42596113681793213, 0.4891957640647888 }, { 0.44627609848976135,
  -0.2649291753768921, 0.47296538949012756, -0.2700652480125427,
  0.4447115361690521, -0.6644209623336792, 0.43864351511001587,
  0.13057145476341248, 0.38153448700904846, 0.43287578225135803 }, {
  0.44761377573013306, -0.27964404225349426, 0.47144728899002075,
  -0.2866366505622864, 0.45033419132232666, -0.6497937440872192,
  0.4380679428577423, 0.1150546595454216, 0.391343355178833, 0.4289560616016388
  }, { 0.4290846884250641, -0.25031933188438416, 0.42947667837142944,
  -0.2567079961299896, 0.43037256598472595, -0.7650051712989807,
  0.4066895842552185, 0.20941932499408722, 0.3541245460510254,
  0.40041694045066833 }, { 0.5199558138847351, -0.21980324387550354,
  0.4631670415401459, -0.27651867270469666, 0.48013609647750854,
  -0.6284698843955994, 0.4315768778324127, 0.29421037435531616,
  0.37770697474479675, 0.414880633354187 }, { 0.35179853439331055,
  -0.2159298062324524, 0.4537796080112457, -0.26939600706100464,
  0.5043035745620728, -0.6542515754699707, 0.4901948571205139,
  0.5454661846160889, 0.4187948405742645, 0.42518454790115356 }, {
  -0.010106919333338737, 0.004475359804928303, 0.011831885203719139,
  0.0023347740061581135, 0.01412924937903881, 0.04035996273159981,
  0.01116417907178402, -0.05056631565093994, 0.012054730206727982,
  0.006604544352740049 }, { 0.017707109451293945, 0.013513759709894657,
  -0.005782492458820343, 0.010859273374080658, -0.003893932094797492,
  0.03987651318311691, -0.005789508577436209, -0.056447528302669525,
  -0.005746860057115555, -0.006472072098404169 }, { 0.003789577865973115,
  -0.005335954949259758, 0.012654170393943787, 0.0063898926600813866,
  0.014640971086919308, 0.04621101915836334, 0.013488966971635818,
  -0.039636291563510895, 0.012730089947581291, 0.010913509875535965 }, {
  -0.0015369183383882046, 0.005471350625157356, 0.0061502521857619286,
  0.0034285960718989372, 0.007057072129100561, 0.027003156021237373,
  0.0068636247888207436, -0.03954155370593071, 0.004650274757295847,
  0.0037534344010055065 }, { -0.0015425966121256351, -0.003100242465734482,
  0.009736061096191406, 0.0009204444359056652, 0.010626270435750484,
  0.04256312549114227, 0.008730685338377953, -0.043148912489414215,
  0.007481274660676718, 0.007902776822447777 }, { -0.006916466634720564,
  0.010189691558480263, 0.015274337492883205, 0.022279955446720123,
  0.01549245323985815, 0.05858184024691582, 0.006524320226162672,
  -0.03847585245966911, 0.004579894710332155, 0.01218155212700367 }, {
  -0.0059191943146288395, 0.011880015023052692, -0.0015437973197549582,
  0.00954253040254116, -0.0016970221186056733, -0.022822292521595955,
  -0.00408344529569149, -0.07529190927743912, -0.0034426965285092592,
  -0.004027289338409901 }, { 0.002155002672225237, -0.006135761737823486,
  0.015392973087728024, -0.00586795574054122, 0.014701003208756447,
  0.05463358014822006, 0.013828868046402931, -0.03820426017045975,
  0.012749378569424152, 0.014512996189296246 }, { 0.007013010326772928,
  -0.018321361392736435, 0.027655690908432007, -0.02128089964389801,
  0.027056558057665825, 0.08393879979848862, 0.026643965393304825,
  -0.031438592821359634, 0.025179145857691765, 0.026807432994246483 }, {
  -0.009060818701982498, -0.014637550339102745, 0.0245140939950943,
  -0.014633459970355034, 0.026211651042103767, 0.07277548313140869,
  0.023219900205731392, -0.06044448912143707, 0.02219962514936924,
  0.02255772426724434 }, { 0.0009890473447740078, 0.0025689988397061825,
  0.0029933019541203976, 0.0026871562004089355, 0.004153409041464329,
  -0.014231826178729534, 0.0028683433774858713, -0.05255261808633804,
  0.0018601162591949105, 0.0037203743122518063 }, { 0.014783969148993492,
  -0.030348604544997215, 0.048568908125162125, -0.03418368101119995,
  0.045904822647571564, 0.21774326264858246, 0.0468745194375515,
  -0.025057200342416763, 0.04436303302645683, 0.04256070405244827 }, {
  -0.001338872709311545, -0.001099711051210761, 0.011798196472227573,
  -0.0010271434439346194, 0.011257215403020382, 0.055040646344423294,
  0.006571569014340639, -0.029846491292119026, 0.009083450771868229,
  0.008606307208538055 }, { -0.0025206380523741245, 0.03125658258795738,
  -0.017243361100554466, 0.03216329589486122, -0.010740770027041435,
  -0.05781843513250351, -0.017374781891703606, -0.04399864003062248,
  -0.016367197036743164, -0.02207805961370468 }, { -0.008935511112213135,
  0.01588786020874977, -0.005458052270114422, 0.015447932295501232,
  0.0002479049435351044, 0.016621612012386322, -0.0034153328742831945,
  -0.05701618641614914, -0.001652541453950107, -0.006199870724231005 }, {
  0.0018021129071712494, -0.004010784439742565, 0.010857501067221165,
  -0.006167122162878513, 0.01268286444246769, 0.04609864205121994,
  0.01222320832312107, -0.03699537366628647, 0.011207222007215023,
  0.009706465527415276 }, { -0.003358280286192894, 0.0069209677167236805,
  0.003744186367839575, 0.000022598034775000997, 0.007120033726096153,
  0.02481597475707531, 0.0039831786416471004, -0.056816235184669495,
  0.003359674010425806, 0.004114761017262936 }, { -0.030529499053955078,
  0.034363728016614914, -0.015255279839038849, 0.031067367643117905,
  -0.017316114157438278, -0.08005756884813309, -0.020900147035717964,
  -0.017726922407746315, -0.021875783801078796, -0.02447391115128994 }, {
  0.00013344670878723264, -0.004767694044858217, 0.019656620919704437,
  -0.004764625336974859, 0.021222280338406563, 0.09208859503269196,
  0.02049538679420948, -0.022420845925807953, 0.01786002889275551,
  0.01997714303433895 }, { 0.00014631978410761803, 0.008409316651523113,
  0.0012459810823202133, 0.0057202852331101894, 0.005349485669285059,
  0.0013218697858974338, 0.001785722910426557, -0.04473695531487465,
  0.005110645201057196, 0.001506762346252799 }, { -0.002060048282146454,
  -0.0010022168280556798, 0.007520562037825584, -0.0009703372488729656,
  0.006972051225602627, 0.06452539563179016, 0.0065904115326702595,
  -0.028183946385979652, 0.005169377662241459, 0.0067565166391432285 }, {
  -0.005371135659515858, -0.015999047085642815, 0.029263461008667946,
  -0.019694972783327103, 0.029128270223736763, 0.04808508977293968,
  0.028227513656020164, -0.04525603726506233, 0.026467733085155487,
  0.02688291110098362 }, { 0.3956967294216156, -0.30071401596069336,
  0.4752607047557831, -0.3055664598941803, 0.45281344652175903,
  -0.6206023097038269, 0.44189783930778503, 0.06217087060213089,
  0.39544960856437683, 0.43739572167396545 }, { -0.21993833780288696,
  -0.21602937579154968, 0.5010220408439636, -0.24192959070205688,
  0.5627127885818481, -0.7517757415771484, 0.47989609837532043,
  0.5445677042007446, 0.4359857141971588, 0.4769592881202698 }, {
  -0.293827623128891, -0.22659969329833984, 0.5350731611251831,
  -0.24201250076293945, 0.5874162912368774, -0.6911905407905579,
  0.4974977374076843, 0.5962449312210083, 0.4659028947353363, 0.4858441948890686
  }, { -0.13362209498882294, -0.20075586438179016, 0.5073968172073364,
  -0.21574439108371735, 0.5423585176467896, -0.8226967453956604,
  0.4961773157119751, 0.5814898014068604, 0.42381197214126587,
  0.40555694699287415 }, { 0.3945615291595459, -0.30794617533683777,
  0.4858875870704651, -0.3100610077381134, 0.45987027883529663,
  -0.5704949498176575, 0.45145004987716675, 0.03575756400823593,
  0.4044911563396454, 0.4486754536628723 }, { 0.3881177306175232,
  -0.2975883185863495, 0.48459023237228394, -0.30436834692955017,
  0.4621533453464508, -0.634148120880127, 0.44884735345840454,
  0.06066117435693741, 0.39942702651023865, 0.442918062210083 }, {
  0.4598709046840668, -0.2672586739063263, 0.48327597975730896,
  -0.2713889479637146, 0.4720040559768677, -0.6245943903923035,
  0.4516040086746216, 0.23443907499313354, 0.3861783742904663,
  0.42826351523399353 }, { 0.48248040676116943, -0.23114001750946045,
  0.4572550654411316, -0.25944364070892334, 0.4942852854728699,
  -0.6639610528945923, 0.43984267115592957, 0.3424535095691681,
  0.4004361927509308, 0.41089051961898804 }, { 0.38496607542037964,
  -0.3036200702190399, 0.47444915771484375, -0.3070754408836365,
  0.45291975140571594, -0.6247242093086243, 0.4432004690170288,
  0.04626859724521637, 0.39626365900039673, 0.4387483298778534 }, {
  0.16463077068328857, -0.23566898703575134, 0.449471652507782,
  -0.2461680769920349, 0.5223954319953918, -0.7245633006095886,
  0.4709729552268982, 0.6249322295188904, 0.38184911012649536,
  0.4182289242744446 }, { -0.20520466566085815, -0.21954932808876038,
  0.5382333397865295, -0.2711770236492157, 0.5803769826889038,
  -0.6825782060623169, 0.5150359272956848, 0.5594297647476196,
  0.4470074474811554, 0.4280882477760315 }, { -0.2052452564239502,
  -0.2987375557422638, 0.5244084000587463, -0.30783239006996155,
  0.5058938264846802, -0.7263019680976868, 0.4874771237373352,
  0.22786666452884674, 0.4228363335132599, 0.4780672490596771 }, {
  0.006423501297831535, -0.00790311861783266, 0.012774823233485222,
  -0.009273654781281948, 0.012359986081719398, 0.05843383073806763,
  0.011961334384977818, -0.03883614391088486, 0.011078624986112118,
  0.01173930149525404 }, { 0.0014385083923116326, -0.0044732727110385895,
  0.015440189279615879, -0.0061906492337584496, 0.014422492124140263,
  0.06662198901176453, 0.014233109541237354, -0.05597100034356117,
  0.0131152905523777, 0.013865616172552109 }, { 0.009637736715376377,
  0.030058089643716812, -0.007750398945063353, 0.031803008168935776,
  -0.00718939583748579, -0.07411515712738037, -0.008559634909033775,
  -0.019085107371211052, -0.011364089325070381, -0.013287690468132496 }, {
  0.004903716500848532, -0.002202908741310239, 0.0075493259355425835,
  -0.002605787478387356, 0.009029371663928032, 0.043410398066043854,
  0.007343624718487263, -0.03680622950196266, 0.007066784892231226,
  0.007688944693654776 }, { 0.009564908221364021, 0.05481602996587753,
  -0.016788091510534286, 0.05179797485470772, -0.026091543957591057,
  -0.13783486187458038, -0.027153389528393745, -0.01847674511373043,
  -0.026059303432703018, -0.030188512057065964 }, { 0.0016651751939207315,
  -0.005048097111284733, 0.01250064093619585, -0.005707516800612211,
  0.012914878316223621, 0.05107787251472473, 0.012088499963283539,
  -0.04519118368625641, 0.011483707465231419, 0.011719024740159512 }, {
  0.0006001264555379748, 0.0013837899314239621, 0.006818774621933699,
  0.0033755304757505655, 0.006554333493113518, -0.00003665871554403566,
  0.005578219890594482, -0.04432947188615799, 0.005049873609095812,
  0.004962805658578873 }, { 0.004503821488469839, -0.003093608422204852,
  0.014094601385295391, 0.0041489084251224995, 0.012278278358280659,
  0.06518924981355667, 0.011578143574297428, -0.04368652030825615,
  0.010912473313510418, 0.0120044881477952 }, { -0.0037537268362939358,
  -0.0002755214227363467, 0.00618172250688076, -0.002148724626749754,
  0.007708885241299868, 0.029431177303195, 0.005798679776489735,
  -0.05353694036602974, 0.006208398379385471, 0.005658458918333054 }, {
  0.0019448136445134878, -0.0026976277586072683, 0.00876267533749342,
  -0.0000970091568888165, 0.012022394686937332, 0.05288229137659073,
  0.009998875670135021, -0.05675194412469864, 0.011053116992115974,
  0.008077314123511314 }, { 0.003996753599494696, 0.00024642248172312975,
  0.014732210896909237, 0.0005698638851754367, 0.012556754052639008,
  0.054665401577949524, 0.010451117530465126, -0.06310147047042847,
  0.006954568438231945, 0.009528204798698425 }, { 0.0058280099183321,
  -0.00258102104999125, 0.010313651524484158, -0.0038629730697721243,
  0.012018734589219093, 0.04469588026404381, 0.011624212376773357,
  -0.032834507524967194, 0.009230989962816238, 0.00894859153777361 }, {
  -0.003170835319906473, 0.029248306527733803, 0.012852590531110764,
  0.024345608428120613, 0.009399308823049068, 0.02461123652756214,
  0.007300689350813627, -0.04759199172258377, 0.008626566268503666,
  -0.0007201972766779363 }, { 0.02862769365310669, 0.04148479178547859,
  0.0012835917295888066, 0.06216878443956375, 0.014748645946383476,
  -0.01936311088502407, 0.011281806044280529, -0.011410423554480076,
  -0.00031697427039034665, -0.0014610219513997436 }, { 0.0190869253128767,
  -0.013382898643612862, 0.03353014215826988, -0.014998090453445911,
  0.035997822880744934, 0.14594082534313202, 0.03475242480635643,
  -0.029255840927362442, 0.033868107944726944, 0.02671659365296364 }, {
  -0.001192377065308392, -0.0027634012512862682, 0.015599570237100124,
  -0.004747576545923948, 0.01570502482354641, 0.04308212921023369,
  0.013200322166085243, -0.035211093723773956, 0.012427289970219135,
  0.009146512486040592 }, { 0.0033591173123568296, 0.01675717532634735,
  0.0016154601471498609, 0.01687380112707615, 0.0033041187562048435,
  -0.01991080492734909, -0.0004345179768279195, -0.03294739872217178,
  -0.0019367106724530458, -0.004603420849889517 }, { 0.0035828121472150087,
  -0.005195597652345896, 0.013006294146180153, -0.005307102110236883,
  0.012347385287284851, 0.055735498666763306, 0.011431930586695671,
  -0.03440462052822113, 0.010198966600000858, 0.010713182389736176 }, {
  -0.0025030390825122595, 0.013939392752945423, -0.005901286844164133,
  0.01259881816804409, -0.005060490220785141, 0.022167406976222992,
  -0.004270714707672596, -0.050579238682985306, -0.006613144651055336,
  -0.008481571450829506 }, { 0.004870634060353041, -0.0026161016430705786,
  0.01613251492381096, -0.0059494515880942345, 0.019811052829027176,
  0.08013129979372025, 0.015556958504021168, -0.05195259302854538,
  0.015604502521455288, 0.014967973344027996 }, { 0.04881030321121216,
  0.021579794585704803, -0.014629039913415909, 0.020981132984161377,
  -0.014194115065038204, -0.02374698780477047, -0.014806374907493591,
  -0.02924659475684166, -0.016147935763001442, -0.017149971798062325 }, {
  -0.0021160561591386795, -0.004959597252309322, 0.01772688701748848,
  -0.0046059261076152325, 0.015790479257702827, 0.06731697916984558,
  0.015668079257011414, -0.03320039063692093, 0.013252184726297855,
  0.013839546591043472 }, { 0.941993772983551, -1.5817229747772217,
  2.0343267917633057, -1.6535866260528564, 2.232057809829712,
  -1.278427004814148, 2.059631109237671, -2.335737705230713, 1.9325844049453735,
  1.9331965446472168 }, { 0.9436568021774292, -1.5791032314300537,
  2.0879499912261963, -1.4951168298721313, 2.2531628608703613,
  -1.2294822931289673, 2.0839295387268066, -2.4484803676605225,
  1.9551223516464233, 1.9740538597106934 }, { -0.22980402410030365,
  0.9199262261390686, -1.3931411504745483, 1.0378587245941162,
  -1.7050687074661255, 4.863880964656175e-10, -1.5698068141937256,
  0.9223605394363403, -1.335978627204895, -1.3027349710464478 }, {
  -0.3382071256637573, 0.9860741496086121, -1.6543004512786865,
  1.0869961977005005, -1.7495276927947998, 0.1413516104221344,
  -1.6589244604110718, 0.9568116068840027, -1.2587254047393799,
  -1.316787838935852 }, { -0.08973576128482819, 1.0692839622497559,
  -1.7261924743652344, 1.1258662939071655, -2.048819065093994,
  8.524442957069667e-11, -1.707221269607544, 0.9763411283493042,
  -1.3384802341461182, -1.5099725723266602 }, { -0.23119568824768066,
  1.1025586128234863, -1.7083741426467896, 1.1952905654907227,
  -2.0976247787475586, 4.2183725262878724e-11, -1.6553181409835815,
  1.043709397315979, -1.353306770324707, -1.5630202293395996 }, {
  -0.2149028778076172, 0.9034178853034973, -1.4059020280838013,
  1.0857110023498535, -1.7785764932632446, 6.785310091572683e-10,
  -1.5982911586761475, 0.9385444521903992, -1.102957844734192,
  -1.2764172554016113 }, { -0.3442114591598511, 0.7093265652656555,
  -1.3323750495910645, 0.7892476320266724, -1.4307119846343994,
  1.2957205308694597e-9, -1.2221505641937256, 0.7406548261642456,
  -1.0390063524246216, -1.0610798597335815 }, { -0.3801349401473999,
  0.8477363586425781, -1.5809834003448486, 0.9098098874092102,
  -1.6288162469863892, 1.2674961080705316e-9, -1.4910979270935059,
  0.8300457000732422, -1.1994421482086182, -1.3756306171417236 }, {
  -0.4026913046836853, 0.9909816980361938, -1.6537928581237793,
  1.0298457145690918, -1.8706167936325073, 6.557077797397781e-11,
  -1.4875438213348389, 0.9636037945747375, -1.3140361309051514,
  -1.321130633354187 }
};

static float intercepts[10] = {
  -0.9423781037330627,
  2.3425614833831787,
  -1.880435824394226,
  2.760684013366699,
  -2.1556267738342285,
  1.9289884567260742,
  -1.943122386932373,
  1.8524644374847412,
  -1.8369754552841187,
  -1.778485655784607
};

static float intercepts1[1] = {
  -0.9438958168029785
};

static float coefficient1[10] = {
  4.518650531768799,
  -3.7139227390289307,
  5.691276550292969,
  -3.7503113746643066,
  5.436307430267334,
  -6.737155914306641,
  5.318873405456543,
  -4.013023376464844,
  4.771977424621582,
  5.26296329498291
};

static float offset[6] = {
  205.08018493652344,
  10.790425300598145,
  10.719943046569824,
  183.248779296875,
  2656.49658203125,
  12.877049446105957
};

static float scale[6] = {
  0.006835445761680603,
  0.08650556206703186,
  0.08758283406496048,
  0.005654274486005306,
  0.00008135510142892599,
  0.10635864734649658
};

static float unity[1] = {
  1.0
};

static char cats_strings[34][128] = {
  "ea75dbfdc4cd33ab059a923fd2b87d67c250a61e8ae64ff03001eb26b4a3c5f1",
  "232d26a984e4c87bf91264837eedc6b5a4a1444a93349be0ac371de77d0d8426",
  "db8c6ac43cd10145ceeb8463a1a3920697e85e7b554bd9f13c58b0b549db7af0",
  "327fa6f438c4bf9d4e01ce8230bd8c36d3f07b1d9d1b1f93ec38c8ebb0747a71",
  "5ed9c9e5e1107cde3924375a33c1250a951395b59d8472f08ac7978b6fc7ce82",
  "32a989965f70a73aa993e76f15344ec10a73ef65c32f47e16825465b246d0730",
  "6c6627b9bede7234a142d117e88d34ad04c9672a27b8fccd122a9442ad218e15",
  "d049e0300c22bf3f4bac34ad19e9b2ef00d433b0717b094bc6657ac94670f3c0",
  "f321a0cb393597da1f2e24598aa3adcb545b24a5fbaac9df87015f30aabded6e",
  "c0fabdb9eea8a2353102665eaa3211e95d3c5826fcc44bb67fc8c5fcd3503d35",
  "24801cbd57aaf8f01a2c5782d8ebeb26e382228eebdd904c9b78562defdad953",
  "6b4b7a9314efb703ba53a8316d02cd0e3408aad93760cc88b0d9b9bdd5891a1a",
  "e34b6f1266cf79b5e6ed49b1038dbe26f8da6d09bb556143ca2e4fb0a4ad065c",
  "ab3e680b0f70d8bb2df694b55c6d78e11dc82973ad20d5f376f30ee8d4a11a0a",
  "cfcaf0d89b776cab25e88e3f034a4993b16d78be249bc23af7bbb8751c7e350f",
  "cc912327aa7f363442b317507d27e4b8133989dc49e9f06c049b794a3bc0dc37",
  "819901d92b3deeb7adfd5b03b3620883abfd4cbe63a34fded376047842b78cda",
  "1763e99cd0ad99710d516d21f150cdd96da78d4a5d735d4061bb54b136f3517c",
  "26a65d430b9e68fae421cac7a9d5de333f79185b3c1db4e9d59cd501f0fd6a51",
  "0c3603e13e24a40b4bf215e3795a9a40d60a8456fb7b63c2d11e81701a231e85",
  "afd4b5db81abc1dd56d271732ed0245f8691bdc5dad3476d6f6356077b1aa1d6",
  "34a97c4109b59b73547f940c1dc8d21c0f187388f2d3a8eecfee7fd867902fd4",
  "ac31ba1c9fdf51baa2a437bfc092a1f732e2a8f066763742b0770a6e26e32f2b",
  "e5e47a373094f3f9b4188c843d5c4bea5a2a4ac4bbbdf7fac7ce39b206257377",
  "15410f23db97054b6eb270efccfb7cb4176f8268142cea16e28b21dc9598700e",
  "f1db8e9ad44e7e1841b14b125ccf35a17e8cffa8f06823bd46cf856e4af263b8",
  "aaf968ba850b4d9affbec493fa0fe0a833e9e463e87a2cce0c8c08a13ccca4a2",
  "a4169b3e9a4c13fc94c7a67ab099ce92cc68ea47abaf1688ab8a17202f8da051",
  "3c5359d2750623f244164c9f45384ef06e75360a76d4dbd04f063f608cccc780",
  "f1f1286515914da97052674ad09e256fc598dccd4d385dad588b6dd2a03e6194",
  "ca98d874b31b6b0b1e2533bc1408d0d6a8bac0a161a691221748163ddcb12103",
  "b1a11736cb8ef5565bff055f3163253813c9c4161304ea3fce55ad805eec174f",
  "8d79ca67d207ac46fde3b25b6e1d51c4daeae308e2f3aa89fc9a24b7bb8d0656",
  "29272c47115b5a93be87e3a9d8739fb2e8a1fea6aa31852af190389734c51946"
};

static char cats_strings2[10][128] = {
  "7a917c2fad1f46426a21f8ecb64a3afbb7a763f80b2190cae4c021e8bd6c71d2",
  "a18ffc9586713699b9fcb936777d28cf9d7a4214a134c52ab6346348ff9ff3e4",
  "deeabd69f5ef24e4e8a7bb8d07fdc8fbdd4ffe702cb1b2e9e45d1010a8b5b610",
  "b2019c9be6a0087ab26f42c5de10595515176eb576277946bf04434c05bde5b7",
  "b15e2f190ad03a8869c3939ab684966a16a06ed55c9afeca4104f3544edc5378",
  "f0cac05641df3d87852f8c07eb49b9070a383c2a89287d5a32593f251002fd6a",
  "d511711f8439e1ba7592ae8330e1d2d8eaf43962b6bd2f27ed9d49c35ee47381",
  "7fc38db11d3600963a728c164a01991a1d627d2b51b7a3d957060c64aa7ec88b",
  "1cea197e5be5bb4fc161c0853cb955a50cb4d63bcd8ef9a2322773c2098ef6dc",
  "c4911d13876783e2a86ab62427e976ad8edc439a011f0d01a4e8dd2c485e4886"
};

static void
matmul (const float *lhs, const float *rhs, int m, int k, int n, float *out)
{
  for (int i = 0; i < m; i++)
    {
      for (int j = 0; j < n; j++)
	{
	  out[i * n + j] = 0.0f;
	  for (int p = 0; p < k; p++)
	    {
	      out[i * n + j] += lhs[i * k + p] * rhs[p * n + j];
	    }
	}
    }
}

static void
add (const float *lhs, const float *rhs, int length, float *out)
{
  for (int i = 0; i < length; i++)
    {
      out[i] = lhs[i] + rhs[i];
    }
}

static void
sub (const float *lhs, const float *rhs, int length, float *out)
{
  for (int i = 0; i < length; i++)
    {
      out[i] = lhs[i] - rhs[i];
    }
}

static void
sigmoid (const float *in, int length, float *out)
{
  for (int i = 0; i < length; i++)
    {
      out[i] = 1.0f / (1.0f + expf (-in[i]));
    }
}

static void
relu (const float *data, int length, float *out)
{
  for (int i = 0; i < length; i++)
    {
      if (data[i] < 0)
	{
	  out[i] = 0;
	}
      else
	{
	  out[i] = data[i];
	}
    }
}

static void
line_concat (const float *in, int in_size, float *out, int out_size)
{
  for (int i = 0; i < in_size; i++)
    {
      out[out_size + i] = in[i];
    }
}

static void
one_hot_encoder (const char *in, const char (*cats)[128], float *out,
		 int out_size)
{
  for (int i = 0; i < out_size; i++)
    {
      if (i < out_size && strcmp (cats[i], in) == 0)
	{
	  out[i] = 1.0f;
	}
      else
	{
	  out[i] = 0.0f;
	}
    }
}

static void
imputer (const int64_t *in, int size, float *out)
{
  for (int i = 0; i < size; i++)
    {
      out[i] = in[i] * 1.0f;
    }
}

static void
scaler (const float *in, const float *offset, const float *scale, int size,
	float *out)
{
  for (int i = 0; i < size; i++)
    {
      out[i] = (in[i] - offset[i]) * scale[i];
    }
}

static int
argmax (const float *in, int in_size)
{
  int out_idx = 0;
  for (int i = 0; i < in_size; i++)
    {
      if (in[i] > in[out_idx])
	{
	  out_idx = i;
	}
    }
  return out_idx;
}

static int
compare_strings (const void *a, const void *b)
{
  const char *str_a = *(const char **)a;
  const char *str_b = *(const char **)b;

  int len = strlen (str_a);
  for (int i = 0; i < len; i++)
    {
      char c1 = str_a[i];
      char c2 = str_b[i];
      if (ISUPPER (c1) && !ISUPPER (c2))
	{
	  return 0;
	}
      else if (!ISUPPER (c1) && ISUPPER (c2))
	{
	  return 1;
	}
      else if (c1 != c2)
	{
	  return c1 < c2;
	}
    }
  return strlen (str_a) > strlen (str_b);
}

static void
truncate_prefix (const char *str, char *result)
{
  const char *underscore_pos = strchr (str, '_');
  if (underscore_pos == NULL)
    {
      strcpy (result, str);
      return;
    }

  size_t len = underscore_pos - str;
  strncpy (result, str, len + 1);
  result[len + 1] = '\0';
}

static void
preprocess (int argc1, const char **argv1, const char *mops,
	    int argc2, int64_t *argv2, char (*in_options)[1024],
	    int64_t * in_modes)
{
  strcpy (in_options[0], mops);

  const char *output_option = "-o";
  const char *macro_prefix = "-D";
  const char *needle = "--param";
  const char *flag_prefix = "-";
  const char *default_option = "-fdefault-option";
  const int default_int_val = 0;
  int m_size = 0;
  for (int i = 0; i < argc1; i++)
    {
      if (strncmp (argv1[i], macro_prefix, 2) == 0)
	{
	  m_size++;
	}
    }
  char *m_options[m_size];
  char output_file[1024];
  int m_index = 0;
  for (int i = 0; i < argc1; i++)
    {
      if (strncmp (argv1[i], macro_prefix, 2) == 0)
	{
	  m_options[m_index] = (char*)argv1[i];
	  m_index++;
	}
      if (strcmp (argv1[i], output_option) == 0)
	{
	  truncate_prefix (argv1[i + 1], output_file);
	}
    }
  strcpy (in_options[1], output_file);
  int in_options_size = 2;
  qsort (m_options, m_size, sizeof (m_options[0]), compare_strings);
  for (int i = 0; i < m_size && in_options_size < M_OPTION_SIZE; i++)
    {
      strcpy (in_options[in_options_size], m_options[i]);
      in_options_size++;
    }

  for (int i = 0; i < argc1 && in_options_size < M_OPTION_SIZE; i++)
    {
      if (strncmp (argv1[i], macro_prefix, 2) != 0
	  && strcmp (argv1[i], output_option) != 0
	  && strncmp (argv1[i], needle, 7) != 0
	  && strncmp (argv1[i], flag_prefix, 1) == 0)
	{
	  strcpy (in_options[in_options_size], argv1[i]);
	  in_options_size++;
	}
    }
  while (in_options_size < M_OPTION_SIZE)
    {
      strcpy (in_options[in_options_size], default_option);
      in_options_size++;
    }

  uint8_t hash[32];
  for (int i = 0; i < M_OPTION_SIZE; i++)
    {
      sha256 (in_options[i], strlen (in_options[i]), hash);
      char hash_str[65];
      for (int j = 0; j < 32; j++)
	{
	  sprintf (hash_str + (j * 2), "%02x", hash[j]);
	}
      strcpy (in_options[i], hash_str);
    }

  for (int i = 0; i < argc2 && i < M_MODE_SIZE; i++)
    {
      if (i < argc2)
	{
	  in_modes[i] = argv2[i];
	}
      else
	{
	  in_modes[i] = default_int_val;
	}
    }
}

static int
graph_infer (int argc1, const char **argv1, const char *mops,
	     int argc2, int64_t *argv2)
{
  static char in_options[M_OPTION_SIZE][1024];
  static int64_t in_modes[M_MODE_SIZE];

  preprocess (argc1, argv1, mops, argc2, argv2, in_options, in_modes);

  const int concat_out_size = 350;
  float concat_result[concat_out_size];
  const int encoder_out_size = 34;
  const int encoder_last_size = 10;
  int concat_size = 0;
  const int size = encoder_out_size;
  for (int i = 1; i < M_OPTION_SIZE; i++)
    {
      float encoder_out[size];
      one_hot_encoder (in_options[i], cats_strings, encoder_out, size);
      line_concat (encoder_out, size, concat_result, concat_size);
      concat_size += size;
    }
  float encoder_out2[encoder_last_size];
  one_hot_encoder (in_options[0], cats_strings2, encoder_out2,
		   encoder_last_size);
  line_concat (encoder_out2, encoder_last_size, concat_result, concat_size);
  concat_size += encoder_last_size;

  float variable[M_MODE_SIZE];
  imputer (in_modes, M_MODE_SIZE, variable);
  float variable1[M_MODE_SIZE];
  scaler (variable, offset, scale, M_MODE_SIZE, variable1);

  float transformed_column[concat_out_size + M_MODE_SIZE];
  line_concat (variable1, M_MODE_SIZE, transformed_column, 0);
  line_concat (concat_result, concat_out_size, transformed_column, 6);

  const int m = 1, k = 356, n = 10;
  float mul_result[n];
  matmul (transformed_column, coefficient[0], m, k, n, mul_result);

  float add_result[n];
  add (mul_result, intercepts, n, add_result);
  float next_activations[n];
  relu (add_result, n, next_activations);

  const int m2 = 1, k2 = 10, n2 = 1;
  float mul_result1[n2];
  matmul (next_activations, coefficient1, m2, k2, n2, mul_result1);
  float add_result1[n2];
  add (mul_result1, intercepts1, n2, add_result1);

  float out_activations_result[n2];
  sigmoid (add_result1, n2, out_activations_result);

  float negative_class_proba[n2];
  sub (unity, out_activations_result, n2, negative_class_proba);
  const int prob_size = n2 + n2;
  float probabilities[prob_size];
  line_concat (negative_class_proba, n2, probabilities, 0);
  line_concat (out_activations_result, n2, probabilities, n2);

  int argmax_output = argmax (probabilities, prob_size);

  return argmax_output;
}

#endif // AI4C_INFER
